
-----RELEASE NOTES--------------------------------------------------------------
--Ver. 1.0.h
--fixed so only regions in the time selection are matched



--this version still contains a lot of debug trace which will output if the
--debug_output flag is left set to true
-----DEBUG CONTROL--------------------------------------------------------------

debug_output = false -- true/false --display debug messages in the console

-----DISPLAY CONSOLE MESSAGE----------------------------------------------------

-- Display a message in the console for debugging, message can be a number variable
-- or a string but not mixed. No line feed character is added.
function Msg(value)
  --returns nothing

  if debug_output then --check if flag is set true (at the start of this script)
    reaper.ShowConsoleMsg(tostring(value) )
  end
end

-----COPY MEDIA ITEM------------------------------------------------------------

function CopyMediaItem(item, track, position)
  --returns new_item media itme

  local new_item = reaper.AddMediaItemToTrack(track)
  local retval, new_item_chunk = reaper.GetItemStateChunk(new_item, '')
  local new_iid = new_item_chunk:match('\nIID (%d+)')

  local retval, item_chunk = reaper.GetItemStateChunk(item, '')

  new_item_chunk = item_chunk:gsub('GUID ({[%x|-]+})\n', 'GUID ' .. reaper.genGuid('') .. '\n' )
  new_item_chunk = new_item_chunk:gsub('\nIID (%d+)', '\nIID ' .. new_iid)

  reaper.SetItemStateChunk(new_item, new_item_chunk)
  reaper.SetMediaItemInfo_Value(new_item, "D_POSITION", position)
  reaper.UpdateItemInProject(new_item)

  return new_item

end

-----CHECK IF WITHIN TIME SELECTION---------------------------------------------
function IsInTimeSelection( s, e )
  --returns true or false

  if s >= start_time and e <= end_time then return true end
  return false
end

-----GET STANDARDIZED NAME AND OTHERS-------------------------------------------

--Processes given take, item and region names to return
--std_full_name, std_root_name, std_chord_name, switches, alias_full_name, alias_root_name
--where
--std_full_name = the standardised full name of root note and chord type
--std_root_name = the preferred root note name
--std_chord_name = the standardised chord type name
--switches = any optional switches after the given name designated by a "-" character
--alias_full_name = the full name using the alias root note name
--alias_root_name = the alias root note name

--*** Note that many of these returned variables are not used but there is needed

function GetStdName ( full_name )
  --returns std_full_name, std_root_name, std_chord_name, switches, alias_full_name, alias_root_name

  local root_alias = { ["Ab"] = "G#", ["A"] = "A", ["A#"] = "Bb",
    ["Bb"] = "A#", ["B"] = "Cb", ["B#"] = "C",
    ["Cb"] = "B", ["C"] = "B#", ["C#"] = "Db",
    ["Db"] = "C#", ["D"] = "D", ["D#"] = "Eb",
    ["Eb"] = "D#", ["E"] = "Fb", ["E#"] = "F",
    ["Fb"] = "E", ["F"] = "E#", ["F#"] = "Gb",
    ["Gb"] = "F#", ["G"] = "G", ["G#"] = "Ab",
  ["xb"] = "x", ["x"] = "x", ["x#"] = "x" }

  local root_pref = { ["Ab"] = "G#", ["A"] = "A", ["A#"] = "A#",
    ["Bb"] = "A#", ["B"] = "B", ["B#"] = "C",
    ["Cb"] = "B", ["C"] = "C", ["C#"] = "C#",
    ["Db"] = "C#", ["D"] = "D", ["D#"] = "D#",
    ["Eb"] = "D#", ["E"] = "E", ["E#"] = "F",
    ["Fb"] = "E", ["F"] = "F", ["F#"] = "F#",
    ["Gb"] = "F#", ["G"] = "G", ["G#"] = "G#",
  ["xb"] = "x", ["x"] = "x", ["#x"] = "x" }

  local switches = "" --return string of -Switches found at end
  local root_name = ""
  local chord_name = ""
  local std_chord_name = "" --return string with standardised chord name

  --Msg("in GetStdName full_name = "..tostring(full_name).."\n")

  if full_name == "" then full_name = "x" end --no name or switches
  if string.match( full_name, "_.*") then full_name = "x" end --no name or switches
  full_name = string.gsub(full_name, "-5", "(b5)") --if there is a -5 chord make it (b5)
  --switches = string.match( full_name, "-.*") --save any switches then remove them from full name
  switches = string.match( full_name, "-%a.*") --save any switches then remove them from full name
  --flat5, switches = string.match( full_name, "(-5?)(-%a.*)") --save any switches then remove them from full name
  
  if switches then full_name = string.sub(full_name, 1, string.find(full_name, "-") - 1 ) end
  if full_name == "" then full_name = "x" end --switches but no name
  root_name, chord_name = string.match(full_name, "(%w[#b]?)(.*)$")
  std_chord_name = chord_name

  --Msg("root_name = "..tostring(root_name).." chord_name = "..tostring(chord_name).."\n")

  if not chord_name or #chord_name == 0 then std_chord_name = "Maj" end --if no Major or minor indicated make it Major
  --std_chord_name = string.gsub(std_chord_name, "-5", "(b5)") --if there is a -5 make it (b5)
  --if flat5 then std_chord_name = "-5" end
  --if string.match(full_name, "-5") then std_chord_name = "(b5)" end
  std_chord_name = string.gsub(std_chord_name, "maj", "Maj") --if there is a maj make it Maj
  std_chord_name = string.gsub(std_chord_name, "[Mm]in", "m") --if there is a Min or min make it m
  std_chord_name = string.gsub(std_chord_name, "Sus", "sus") --if there is Sus replace it with just sus
  

  local std_root_name = root_pref[root_name] --return string with standardised root chord name
  local std_full_name = std_root_name .. std_chord_name --return string standardised full name
  local alias_root_name = root_alias[root_name] --return string alias root name
  local alias_full_name = alias_root_name .. std_chord_name --return string alias full name


  return std_full_name, std_root_name, std_chord_name, switches, alias_full_name, alias_root_name

end

-----GET ITEM LENGTH------------------------------------------------------------

function Get_item_length(item)
  --return item_len

  local item_len = reaper.GetMediaItemInfo_Value( item, "D_LENGTH" )

  return item_len
end

-----GET REGION LENGTH----------------------------------------------------------

function Get_region_length(region)
  --return region_len

  local retval_region, is_rgn, region_pos, region_end, region_name, region_index, region_color = reaper.EnumProjectMarkers3(0, region)
  region_len = region_end - region_pos

  return region_len
end

-----MOVE MATCHED ITEMS CONTAINED IN A TABLE TO FILL A REGION-------------------

function Move_matches(move_table, region) --***maybe enhance to be able to move a whole matching linked section
  --returns nothing  --***maybe return rnd values

  local retval_region, is_rgn, region_pos, region_end, region_name, region_index, region_color = reaper.EnumProjectMarkers3(0, region)
  if #move_table > 0 then --some matches found so ready to move them
    --just modified Xray's code here to change table from items to move_table
    local last_end = region_pos
    repeat
      local id = math.random( 1, #move_table ) --pick random entries from move table #gives total number in table
      local track = reaper.GetMediaItemTrack( move_table[id] )
      local item_len = reaper.GetMediaItemInfo_Value( move_table[id], "D_LENGTH" )
      --***check item is shorter than the region
      --Msg("CopyMediaItem of length "..tostring(item_len).." to "..tostring(region).."\n")
      local new_item = CopyMediaItem(move_table[id], track, last_end)
      local new_item_len = reaper.GetMediaItemInfo_Value( new_item, "D_LENGTH" )
      local new_item_end = last_end + new_item_len
      if new_item_end > region_end then reaper.SetMediaItemInfo_Value( new_item, "D_LENGTH", region_end - last_end ) end
      last_end = new_item_end
    until last_end >= region_end
  end
end

-----MOVE MATCHED LINKED SECTION------------------------------------------------

--if item is a single linked one ie L1 only then fit it to start of first region
--otherwise fit first to end of region
--copy mid ones to mid regions (should be exact size of mid regions)
--fit last one to beginning of last region

function Move_linked_items(move_link_table, region)
  --return moved_ok_flag, num_items_moved***


  --move_link_table[link_level][section_num]


  --fit first item to end of first region
  local retval_region, is_rgn, region_pos, region_end, region_name, region_index, region_color = reaper.EnumProjectMarkers3(0, region) --***chk other enum calls
  local track = reaper.GetMediaItemTrack(move_link_table[1])
  local item_len = reaper.GetMediaItemInfo_Value( move_link_table[1], "D_LENGTH" )
  --Msg("CopyMediaItem of length "..tostring(item_len).." to "..tostring(region_end - item_len).."\n")
  if #move_link_table == 1 then CopyMediaItem(move_link_table[1], track, region_pos) --if it is the only linked item put it at the start of region
  else CopyMediaItem(move_link_table[1], track, region_end - item_len) --if there are multiple linked items put it at the end of region
  end

  for j = 2, #move_link_table do
    --middle or last so fit to start of region
    local retval_region, is_rgn, region_pos, region_end, region_name, region_index, region_color = reaper.EnumProjectMarkers3(0, region + j - 1)
    local item_len = reaper.GetMediaItemInfo_Value( move_link_table[j], "D_LENGTH" )
    --Msg("CopyMediaItem of length "..tostring(item_len).." to "..tostring(region_pos).."\n")
    CopyMediaItem(move_link_table[j], track, region_pos )

  end

  return moved_ok_flag, num_items_moved ---***
end

-----CHECK FOR MATCHES BETWEEN ITEM OR LINKED ITEMS AND REGION LIST-------------

function Chk_match(item_id, region)
  --returns item_match_flag, match_priority, num_linked_matches, num_linked_sections

  --initialize color table values to suit operating system running
  local os_type = reaper.GetOS() --Find out whether program is running on a Windows or Mac or Linux

  --Color code table Windows                        B  G  R
  local anywhere_color = 19340004 -----------------27 1A E4 the color to signify use anywhere 0x01271AE4
  local count_in_color = 29393151 -----------------C0 80 FF
  local intro_post_fill_color = 28184951 ----------AE 11 77
  local intro_color = 31987359 --------------------E8 16 9F
  local intro_fill_color = 32342199 ---------------ED 80 B7
  local verse_post_fill_color = 28190481 ----------AE 27 11
  local verse_color = 32208439 --------------------EB 76 37
  local verse_fill_color = 32620145 ---------------F1 BE 71
  local verse_ending_color = 32886935 -------------FE D0 97
  local bridge_post_fill_color = 18115022 ---------14 69 CE
  local bridge_color = 19957226 -------------------30 85 EA
  local bridge_fill_color = 23373039 --------------64 A4 EF
  local pre_chorus_post_fill_color = 18133966 -----14 B3 CE
  local pre_chorus_color = 19976426 ---------------30 D0 EA
  local pre_chorus_fill_color = 26732532 ----------97 E7 F4
  local chorus_post_fill_color = 19362827 ---------27 74 0B
  local chorus_color = 20688401 -------------------3B AE 11
  local chorus_fill_color = 24898896 --------------7B ED 50
  local chorus_ending_color = 28769950 ------------B6 FE 9E
  local drum_riff_color = 17897331 ----------------11 17 73
  local hold_color = 29343679 ---------------------BF BF BF
  local shot_color = 25132927 ---------------------7F 7F 7F
  local rest_color = 16777216 ---------------------00 00 00

  if os_type ~= "Win32" and os_type ~= "Win64" then
    --color code table Mac                          R  G  B
    anywhere_color = 31726119 ---------------------E4 1A 27 the color to signify use anywhere 0x01271AE4
    count_in_color = 33521856 ---------------------FF 80 C0
    intro_post_fill_color = 24580526 --------------77 11 AE
    intro_color = 27203304 ------------------------9F 16 E8
    intro_fill_color = 28803309 -------------------B7 80 ED
    verse_post_fill_color = 17901486 --------------11 27 AE
    verse_color = 20412139 ------------------------37 76 EB
    verse_fill_color = 24231665 -------------------71 BE F1
    verse_ending_color = 26726654 -----------------97 D0 FE
    bridge_post_fill_color = 30304532 -------------CE 69 14
    bridge_color = 32146736 -----------------------EA 85 30
    bridge_fill_color = 32482404 ------------------EF A4 64
    pre_chorus_post_fill_color = 30323476 ---------CE B3 14
    pre_chorus_color = 32165936 -------------------EA D0 30
    pre_chorus_fill_color = 32827287 --------------F4 E7 97
    chorus_post_fill_color = 17527847 -------------0B 74 27
    chorus_color = 17935931 -----------------------11 AE 3B
    chorus_fill_color = 22080891 ------------------50 ED 7B
    chorus_ending_color = 27197110 ----------------9E FE B6
    drum_riff_color = 24319761 --------------------73 17 11
    hold_color = 29343679 -------------------------BF BF BF
    shot_color = 25132927 -------------------------7F 7F 7F
    rest_color = 16777216 -------------------------00 00 00
  end

  --if is_rgn and IsInTimeSelection( region_pos, region_end ) then --*** check this

  --START LINK LOOP (OR ONCE THROUGH FOR SINGLE ITEM MATCHES)
  local item_match_flag = true
  local link_count_done = false
  local num_linked_matches = 0 --number of linked matching items in a section
  local num_linked_sections = 0 -- number of linked complete sections
  local linked_section_flag = false --assume by default that this will be a single item match

  --LOOP TO CHECK FOR SINGLE AND LINKED MATCHES
  ------------------------------------------------------------------------------
  --if there are a number of consecutive items to match consecutive regions because -L switches found.
  --the repeat/until loop checks if link_count_done is set true at the end of the loop (the until statement)
  --for non-linked items link_count_done is set true at the start so only one time through the repeat/until loop.
  --the num_linked_matches variable will return 1 for single item matches and >1 for linked matches

  repeat
    --*** count variables not defined at this point reloacte test?
    if (region) > count_markers_regions - 1 or (item_id) > count_sel_items then
      break
    end --check items and region in range

    --Get region details
    local retval_region, is_rgn, region_pos, region_end, region_name, region_index, region_color = reaper.EnumProjectMarkers3(0, region)
    local full_region_name, region_root, std_region_chord, _, alias_full_region_name, alias_region_root = GetStdName(region_name)
    local region_verse_fills = ((region_color == verse_post_fill_color) or (region_color == verse_fill_color)) --verse fills flag
    local region_chorus_fills = ((region_color == chorus_post_fill_color) or (region_color == chorus_fill_color)) --chorus fills flag


    --Get item details
    local item = init_sel_items[item_id]
    local take = reaper.GetActiveTake( item )
    if take then take_name = reaper.GetTakeName( take ) end
    local item_color = reaper.GetMediaItemInfo_Value( item, "I_CUSTOMCOLOR" )
    local full_item_name, item_root, std_item_chord, switches, alias_full_item_name, alias_root_name = GetStdName(take_name)
    use_chord_anywhere = (item_color == anywhere_color) --use_chord_anywhere is set to 'true' if item is anywhere color
    local link_this_to_next = false
    local link_level = 0


    if switches then link_this_to_next = (string.find( take_name, "-L[12345]") ~= nil) end --link_this_to_next is set true if match with -L found
    if link_this_to_next then --this is a linked item so will need to loop around checking the next items and regions match too
      link_level = tonumber(string.match( switches, "-L([12345])")) --***may not need level

      if link_level == 1 then --***need to check if linked_section_flag is already set and break as this is new start -L1
        if linked_section_flag then break end --if find another -L1 when in a section it is start of a new section so break loop
        linked_section_flag = true --now processing a linked section
        link_count_done = false --don't stop looping looking for the next -L items
      elseif not linked_section_flag then --***check what happens here seems to be if higher L flag found and its not in a section then break
        item_match_flag = false
        match_priority = 0
        break --if linked item does not start at L1 ***check if this fails
      end

    else link_count_done = true --not linked so just continue out of the bottom on the repeat/until loop after a single pass through
    end

    --have got next item in loop or first one sent by function call
    ----------------------------------------------------------------------------

    --ALREADY IN LOOP PROCESSING LINKED ITEMS
    ----------------------------------------------------------------------------
    if linked_section_flag then --already processing a linked section so continue
      if not link_this_to_next then --no more linked sections so end loop and return with flags
        break
      end
      --and continue to match tests

      --JUST ENTERED FROM FUNCTION CALL NOT PROCESSING LINKED ITEMS
      --------------------------------------------------------------------------
    else --not processing a linked section *** not used - can remove this else
      --just continue to match tests

    end

    --MATCH TESTS FOR DIFFERENT PRIORITY MATCHES
    ----------------------------------------------------------------------------
    --get any name aliases and standard names and check for special regions such as fills and set flags if found

    --1. test if both name and color match for linked and non-linked items
    if ((full_item_name == full_region_name or alias_full_item_name == full_region_name) and (region_color == item_color)) then
      item_match_flag = true
      num_linked_matches = num_linked_matches + 1
      Match_name_and_color = true
      match_priority = 5 --indicates a full name and color match for single item
      if linked_section_flag then
        match_priority = 6 --indicates a full name and color match for linked item
        --link_match = true
        --Msg("Got match\n")
      end


      --2. Name and verse color match and this is a verse fills region
    elseif((full_item_name == full_region_name or alias_full_item_name == full_region_name) and region_verse_fills and (verse_color == item_color)) then
      item_match_flag = true
      num_linked_matches = 1
      Match_name_and_color_verse = true
      match_priority = 4 --indicates a name and verse color match for single item

      --3. Name and chorus color match and this is a chorus fills region
    elseif((full_item_name == full_region_name or alias_full_item_name == full_region_name) and region_chorus_fills and (chorus_color == item_color)) then
      item_match_flag = true
      num_linked_matches = 1
      Match_name_and_color_chorus = true
      match_priority = 3 --indicates a name and chorus color match for single item

      --[[4. Only check if name matches if the color of the item is the 'fit anywhere' red (R G B = hex E4 1A 27)
    elseif (use_chord_anywhere and (full_item_name == full_region_name or alias_full_item_name == full_region_name)) then
      item_match_flag = true
      num_linked_matches = 1
      Match_name_only = true
      match_priority = 2 --indicates a name and universal red color match for single item
      --]]

      --4. Only check if name matches if the color of the item is the 'fit anywhere' red (R G B = hex E4 1A 27) for linked and non - linked items
    elseif (use_chord_anywhere and (full_item_name == full_region_name or alias_full_item_name == full_region_name)) then
      item_match_flag = true
      num_linked_matches = num_linked_matches + 1
      Match_name_only = true
      match_priority = 2 --indicates a name and universal red color match for single item
      if linked_section_flag then
        match_priority = 6 --indicates a name and universal red color match for linked item
        --link_match = true
        --Msg("Got match\n")
      end

      
      -- Needs to be able to use -L as well as empty chord root
      --6. Match any region (used for matching scale items to any regions)
    elseif (is_scale_track and (take_name == "")) then --if just scale match
      num_linked_matches = num_linked_matches + 1
      Match_name_only = true
      match_priority = 2 --indicates a name and universal red color match for single item
      if linked_section_flag then
        match_priority = 6 --indicates a name and universal red color match for linked item
        --link_match = true
        --Msg("Got match\n")
      end      

      --if one linked section fails to match name and color then break loop
    elseif linked_section_flag then
      --Msg("Match failed\n")
      item_match_flag = false --reset the match flag if one linked item fails
      match_priority = 0
      break

      --5. Only check if color matches (used for matching drums items to regions)
    elseif (is_drum_track and (region_color == item_color)) then --if just color match
      item_match_flag = true
      num_linked_matches = 1
      Match_color_only = true
      match_priority = 1 --indicates a color only  match for single item
      
     

    elseif true then
      --table.insert( delete_items, item ) --No match so put in delete item table *** maybe not delete yet check!!!!
      item_match_flag = false
      match_priority = 0
      --
    end --END OF MATCH TESTS

    ----------------------------------------------------------------------------

    item_id = item_id + 1
    region = region + 1

  until link_count_done --END LOOP TO CHECK FOR SINGLE AND LINKED MATCHES

  ------------------------------------------------------------------------------

  return item_match_flag, match_priority, num_linked_matches, num_linked_sections
end --END CHK MATCH FUNCTION

-----MAIN FUNCTION--------------------------------------------------------------
function Main()

  local clock = os.clock
  local take = reaper.GetActiveTake( init_sel_items[1] ) --get active take for the selected media
  local source = reaper.GetMediaItemTake_Source( take ) --if not MIDI then get the wav or mp3 etc
  local filename = reaper.GetMediaSourceFileName( source, "" ) --Get file name of source media
  --Check if the media is a drum track from its file name
  is_drum_track = (string.find( filename, ("Drums" or "-drum")) ~= nil)--if it is drum track set as true
  is_scale_track = (string.find( filename, ("Scale" or "scale")) ~= nil)--if it is Scale track set as true

  local cursor_pos = reaper.GetCursorPosition()
  marker_idx, region_idx = reaper.GetLastMarkerAndCurRegion(0, cursor_pos)
  start_time, end_time = reaper.GetSet_LoopTimeRange2(0, false, false, 0, 0, false)
 
  --get the first and last regions in the time selection
  
  markeridx,start_region = reaper.GetLastMarkerAndCurRegion(0, start_time)
  markeridx, end_region = reaper.GetLastMarkerAndCurRegion(0, end_time - 0.5) --the -0.5 is just a fudge to stop the next region
                                                                              --being included when the time selection is 
                                                                              --exactly on the region boundary
  
Msg("start_time = "..tostring(start_time).."\n")
Msg("end_time = "..tostring(end_time).."\n")

Msg("start_region = "..tostring(start_region).."\n")
Msg("end_region = "..tostring(end_region).."\n")
Msg("count_markers_regions = "..tostring(count_markers_regions).."\n")
Msg("region_idx = "..tostring(region_idx).."\n")

  --Msg("Process just this single region = "..tostring(region_idx).."\n")
  --if region_idx == -1 then return end
  --ProcessRegion( region_idx )

  --MAIN REGION AND ITEM LOOPS FOLLOW HERE


  --Variables to initialize and define before starting the region loop
  ----------------------------------------------------------------------------
  match_count = 0 --The total number of item-region matches found used as match tables index
  link_match_count = 0 --The total number of linked item-region matches found --*** for debug purposes
  local link_levels_matched = 0 --keep track of how many of the consecutive linked items are matched.***(nearly?-transp)
  local num_link_matches = 0
  local r = start_region --start region loop at start of time selection
  local single_region_only = false
  if start_time == end_time then single_region_only = true end -- If no time selection
  if single_region_only == true then r = region_idx end --single region only
  ----------------------------------------------------------------------------


  --REGION LOOP START

  while r <= end_region do

    --*** match_table[6] will need to have an extra index to store multiple
    --*** matches of riffs or linked sections it will need to allow for multiple
    --*** matches with different number of linked items in each matched section or riff
    --*** probably index these tables by a riff count variable

    --define tables inside regions loop so they will get cleared at beginning for each region
    local match_table = {} --6 tables, one for each priority
    for k = 1, 6 do
      match_table[k] = {} --start off each priority table empty at beginning of region loop
    end
    for k = 1, 10 do --allow for up to 10 links in each section
      match_table[6][k] = {} --match_table[6] is for linked items
      --indexed as match_table[6][link_level][matched_section_count]
    end

    --------------------------------------------------------------------------

    --ITEM LOOP START
    for i, item in ipairs(init_sel_items) do
      Item = item --make Item a global copy of local item
      ------------------------------------------------------------------------

      --chk for all single and linked matching items and write to match table
      match_flag, match_priority, num_link_matches = Chk_match(i, r)
      if match_flag == true then
        --push matching items into different tables based on priority of match
        for j = 1, 5 do -- 5 levels of priority
          if match_priority == j then
            table.insert(match_table[j], init_sel_items[i])
          end
        end
        if match_priority == 6 then
          Msg("got priority 6 match of "..tostring(num_link_matches).." links\n")
          for l = 1, num_link_matches do
            Msg("table.insert match_table[6]["..tostring(l).."] item length = "..tostring(Get_item_length(init_sel_items[i + l - 1])).."\n")
            table.insert(match_table[6][l], init_sel_items[i + l - 1]) --***maybe add dimension to match_table[6]
          end --***to store multiple matches of sections
        end
      end
    end --END OF ITEMS LOOP
    --------------------------------------------------------------------------

    --MOVE MATCHING ITEMS
    local move_table = {} --this table is a list of valid matches(or single items for linked sections) to be randomly moved to this region
    local move_link_table = {}


    --check first link is smaller or equal to first region
    --check all middle one are exact match with time length
    --check last link is smaller or equal to last region
    --do this for all sections and discard any that don't fit
    --then pick random section from the remaining ones
    --may need to keep a region done flag once higher linked items are moved
    --need to check if too long for region if next region is the same


    -----DELAY FUNCTION FOR DEBUG---------------------------------------------
    function sleep(n) -- wait n seconds
      local t0 = clock()
      while clock() - t0 <= n do
      end
    end

    --------------------------------------------------------------------------


    Msg("In region "..tostring(r).." finshed item loop\n")
    Msg("#match_table[6][1] = "..tostring(#match_table[6][1]).."\n")
    if r == 1 then
      --Msg("Links found = L1 "..tostring(#match_table[6][1]).." link item length = "..tostring(Get_item_length(match_table[6][1][1])).."\n")
      --Msg("Links found = L2 "..tostring(#match_table[6][2]).." link item length = "..tostring(Get_item_length(match_table[6][2][1])).."\n")
      --Msg("Links found = L3 "..tostring(#match_table[6][3]).." link item length = "..tostring(Get_item_length(match_table[6][3][1])).."\n")
      --Msg("Links found = L4 "..tostring(#match_table[6][4]).." link item length = "..tostring(Get_item_length(match_table[6][4][1])).."\n")
    end
    if #match_table[6][1] > 0 then --if linked matches found
      --local rnd_id = math.random(1, #match_table[6][1]) --pick one random of the number of fitting linked sections found
      --Msg("rnd_id = "..tostring(rnd_id).."\n")

      --test if first link is smaller than section
      --if Get_item_length(match_table[6][1][j]) > Get_region_length(r) then
      --delete from table
      --end
      local j = 1
      while j <= #match_table[6][1] do --loop through the linked sections

        --delete any sections from match table if too long for region
        --also delete any middle sections which are too short
        local k = 1
        while match_table[6][k][j] ~= nil do
          --Msg("for L"..tostring(k).."\n")
          --Msg("Get_item_length(match_table[6][k][j] = "..tostring(Get_item_length(match_table[6][k][j])).."\n")
          --Msg("Get_region_length(r + k - 1) = "..tostring(Get_region_length(r + k - 1)).."\n")

          --sleep(5)

          --check if any item is longer than the region or if the middle items are shorter than region
          --Msg("L"..tostring(k).." match_table[6]["..tostring(k + 1).."]["..tostring(j).."] ~= nil is "..tostring(match_table[6][k + 1][j] ~= nil).."\n")
          if (Get_item_length(match_table[6][k][j]) > Get_region_length(r + k - 1)) or ( (k ~= 1) and (match_table[6][k + 1][j] ~= nil) and (Get_item_length(match_table[6][k][j]) < Get_region_length(r + k - 1))) then

            local l = 1
            while match_table[6][l][j] ~= nil do
              --Msg("removing from match table link "..tostring(l).." for section "..tostring(j).."\n")
              --Msg("length of table [6]["..tostring(l).."]["..tostring(j).."] before is "..tostring(#match_table[6][l]).."\n")
              table.remove(match_table[6][l], j)
              l = l + 1
            end
            j = j - 1
            break
          end
          k = k + 1
        end --end of while match_table loop
        j = j + 1
      end --end of while j loop
    end
    --any items left in table?
    --Msg("checking if any items left, #match_table[6][1] ="..tostring(#match_table[6][1]).."\n")
    if #match_table[6][1] > 0 then --if linked matches found
      --pick a random linked section match from those left
      local rnd_id = math.random(1, #match_table[6][1]) --pick one random of the number of fitting linked sections remaining

      move_link_table = {}
      k = 1
      while match_table[6][k][rnd_id] ~= nil do
        table.insert(move_link_table, match_table[6][k][rnd_id])
        k = k + 1
      end
      --Msg("moving "..tostring(#move_link_table).." links to region "..tostring(r).."\n")
      Move_linked_items(move_link_table, r)
      r = r + #move_link_table

    else
      for j = 1, 5 do
        if #match_table[j] > 0 then --test for all other priority matches
          move_table = match_table[j]
        end
      end
      --Msg("moving "..tostring(#move_table).." items to region "..tostring(r).."\n")
      Move_matches(move_table, r)
      r = r + 1
    end
    if single_region_only then break end --if only single region selected we are done
  end --END OF REGIONS LOOP

  ------------------------------------------------------------------------------
  --delete the unmoved items
  for i, item in ipairs( init_sel_items ) do
  local track = reaper.GetMediaItemTrack(item)
  reaper.DeleteTrackMediaItem( track, item )
  end

end --END OF MAIN FUNCTION

--------------------------------------------------------------------------------

-----SCRIPT STARTS HERE---------------------------------------------------------

-- Check if there are items selected
count_sel_items = reaper.CountSelectedMediaItems(0)
count_markers_regions, num_markers, num_regions = reaper.CountProjectMarkers( 0 )

if count_sel_items > 0 or num_regions == 0 then
  reaper.PreventUIRefresh(1)
  reaper.Undo_BeginBlock() -- Begining of the undo block. Leave it at the top of your main function.
  reaper.ClearConsole()
  init_sel_items = {}
  -- Save item selection
  for i = 0, reaper.CountSelectedMediaItems(0) - 1 do
    init_sel_items[i + 1] = reaper.GetSelectedMediaItem(0, i)
  end

  -----CALL MAIN FUNCTION-------------------------------------------------------
  Main()
  -----CLEAN UP AT END----------------------------------------------------------
  reaper.Undo_EndBlock("ReaTrak Move and match", - 1) -- End of the undo block. Leave it at the bottom of your main function.
  reaper.UpdateArrange()
  reaper.PreventUIRefresh(-1)

end

-----SCRIPT FINISHES HERE-------------------------------------------------------
