--[[
	Lokasenna_GUI 2.0 preview
	
	-- Tabs and layer sets
	-- Accessing elements' parameters

]]--

-----DEBUG CONTROL--------------------------------------------------------------

debug_output = true -- true/false --display debug messages in the console

-----DISPLAY CONSOLE MESSAGE----------------------------------------------------

-- Display a message in the console for debugging, message can be a number variable
-- or a string but not mixed. No line feed character is added.
function Msg(value)
  --returns nothing

  if debug_output then --check if flag is set true (at the start of this script)
    reaper.ShowConsoleMsg(tostring(value) )
  end
end


local dm, _ = debug_mode
local function Msg(str)
	reaper.ShowConsoleMsg(tostring(str).."\n")
end

local info = debug.getinfo(1,'S');
script_path = info.source:match[[^@?(.*[\/])[^\/]-$]]


-- I hate working with 'requires', so I've opted to do it this way.
-- This also works much more easily with my Script Compiler.
local function req(file)
	
	if missing_lib then return function () end end
	
	local ret, err = loadfile(script_path .. file)
	if not ret then
		reaper.ShowMessageBox("Couldn't load "..file.."\n\nError: "..tostring(err), "Library error", 0)
		missing_lib = true          
		return function () end

	else 
		return ret
	end     

end



    

-- The Core library must be loaded prior to any classes, or the classes will throw up errors
-- when they look for functions that aren't there.
req("ReaTrak_Core.lua")()

-- For better cross-platform behavior.
local sep = GUI.file_sep

req("ReaTrak_Classes/Class - Label.lua")()
req("ReaTrak_Classes/Class - Knob.lua")()
req("ReaTrak_Classes/Class - Tabs.lua")()
req("ReaTrak_Classes/Class - Slider.lua")()
req("ReaTrak_Classes/Class - Button.lua")()
req("ReaTrak_Classes/Class - Menubox.lua")()
req("ReaTrak_Classes/Class - Textbox.lua")()
req("ReaTrak_Classes/Class - Frame.lua")()
req("ReaTrak_Classes/Class - Options.lua")()
--[[ Old Libray
req("Classes"..sep.."Class - Label.lua")()
req("Classes"..sep.."Class - Knob.lua")()
req("Classes"..sep.."Class - Tabs.lua")()
req("Classes"..sep.."Class - Slider.lua")()
req("Classes"..sep.."Class - Button.lua")()
req("Classes"..sep.."Class - Menubox.lua")()
req("Classes"..sep.."Class - Checklist.lua")()
req("Classes"..sep.."Class - Radio.lua")()
req("Classes"..sep.."Class - Textbox.lua")()
req("Classes"..sep.."Class - Frame.lua")()
--]]
-- If any of the requested libraries weren't found, abort the script.
if missing_lib then return 0 end



--GUI Size


GUI.name = "ReaTrak Studio"
GUI.x, GUI.y, GUI.w, GUI.h = 0, 0, 915, 770
GUI.anchor, GUI.corner = "mouse", "C"


 
    
   
  local function btn_click() 
	
	--reaper.ShowMessageBox("Yay, you clicked a button. Now what?", "<(^^<)", 0)
	
	local tab_num = GUI.Val("tabs")
	Msg("Displaying values for tab "..tostring(tab_num))
	
	-- The '+ 2' here is just to translate from a tab number to its' 
	-- associated z layer. More complicated scripts would have to 
	-- actually access GUI.elms.tabs.z_sets[tab_num] and iterate over
	-- the table's contents (see the call to GUI.elms.tabs:update_sets
	-- below)
	for k, v in pairs(GUI.elms_list[tab_num + 2]) do
		
		local val = GUI.Val(v)
		if type(val) == "table" then
			local str = ""
			for i = 1, #val do
				str = str..", "..tostring(val[i])
			end
			val = string.sub(str, 3)
		end
		Msg("\t"
			..tostring(v)
			.."\t\t"
			..tostring(val)
		   )
		
	end
    
	
end 


--[[     

	New elements are created by:
	
	GUI.New(name, class, params)
	
	and can then have their parameters accessed via:
	
	GUI.elms.name.param
	
	ex:
	
	GUI.New("my_new_label", "Label", 1, 32, 32, "This is my label")
	GUI.elms.my_new_label.color = "magenta"
	GUI.elms.my_new_label.font = 1
	
	
		Classes and parameters
	
	Button          name,      z,      x,      y,      w,      h, caption, func[, ...]
	Checklist     name,      z,      x,      y,      w,      h, caption, opts[, dir, pad]
	Frame          name,      z,      x,      y,      w,      h[, shadow, fill, color, round]
	Knob          name,      z,      x,      y,      w,      caption, min, max, steps, default[, vals]     
	Label          name,      z,      x,      y,          caption[, shadow, font, color, bg]
	Menubox          name,      z,      x,      y,      w,      h, caption, opts
	Radio          name,      z,      x,      y,      w,      h, caption, opts[, dir, pad]
	Slider          name,      z,      x,      y,      w,      caption, min, max, steps, handles[, dir]
	Tabs          name,      z,      x,      y,           tab_w, tab_h, opts[, pad]
	Textbox          name,      z,      x,      y,      w,      h[, caption, pad]

	
]]--

-- Button Colors  = {r, g, b, transparency}

GUI.colors["count_in"] = {255, 124, 192, 255}
GUI.colors["intro_post_fill"] = {119, 17, 174, 255}
GUI.colors["intro"] = {159, 22, 232, 255}
GUI.colors["intro_fill"] = {183, 128, 237, 255}
GUI.colors["verse_post_fill"] = {17, 39, 174, 255}
GUI.colors["verse"] = {55, 118, 235, 255}
GUI.colors["verse_fill"] = {113, 190, 241, 255}
GUI.colors["verse_ending"] = {151, 208, 245, 255}
GUI.colors["bridge_post_fill"] = {206, 105, 20, 255}
GUI.colors["bridge"] = {234, 133, 48, 255}
GUI.colors["bridge_fill"] = {239, 164, 100, 255}
GUI.colors["pre_chorus_post_fill"] = {206, 179, 20, 255}
GUI.colors["pre_chorus"] = {234, 208, 48, 255}
GUI.colors["pre_chorus_fill"] = {244, 231, 151, 255}
GUI.colors["chorus_post_fill"] = {11, 116, 39, 255}
GUI.colors["chorus"] = {17, 174, 59, 255}
GUI.colors["chorus_fill"] = {80, 237, 123, 255}
GUI.colors["chorus_ending"] = {158, 254, 182, 255}
GUI.colors["play_anywhere"] = {228, 26, 39, 250}
GUI.colors["drum_riff"] = {115, 23, 17, 255}
GUI.colors["hold"] = {191, 191, 191, 255}
GUI.colors["shot"] = {127, 127, 127, 255}
GUI.colors["rest"] = {0, 0, 0, 255}

--Text Colors

GUI.colors["btn_txt1"] = {255, 255, 255, 255} --white
GUI.colors["btn_txt2"] = {155, 155, 155, 255} --gray
GUI.colors["btn_txt3"] = {0, 0, 0, 255} --black


--Tabs

GUI.New("tabs",      "Tabs",           1, 0, 0, 25, 20, "Tools,Chord Scales,All Chords", 60)
--GUI.New("tab_bg",     "Frame",          2, 0, 0, 600, 20, true, true, "elm_bg", 1)
GUI.elms.tabs.col_txt = "chorus_fill"

-- Telling the tabs which z layers to display
-- See Classes/Tabs.lua for more detail
GUI.elms.tabs:update_sets(
	--  Tab
	--               Layers
	{     [1] =     {3,6},
		[2] =     {2,4,7}, --Include layer 2,6 on Tab 2 Chord Root Radio and Insert Root Note Button
		[3] =     {2,5,6}, --Include layer 2 on Tab 3 Chord Root Radio and Insert Root Note Button
		[4] =     {6},
		[5] =     {7},
		[6] =     {8},
		[7] =     {9},
		[8] =     {10},
		[9] =     {11},
		[10] =     {12},
		[11] =     {13},
		[12] =     {14},
		[13] =     {15},
		[14] =     {16},
		[15] =     {17},
		[16] =     {18},
		[17] =     {19},
		[18] =     {20},
		[19] =     {21},
		[20] =     {22},
		
	}
)

-- Notice that layers 1 and 2 aren't assigned to a tab; this leaves them visible
-- all the time.

-----------------------------------------------------------------------------------
--Tools Buttons Tab 1 (layer 3)
-----------------------------------------------------------------------------------

--Tools Buttons Functions
---Sections

function btn_click_sect_help()
    commandID1 = reaper.NamedCommandLookup("_RSbe31a3de2526d47fa8357af06379275cceb291c2")
    reaper.Main_OnCommand(commandID1, 0) -- Script: ReaTrak sections help.lua
    end


function btn_click_count_in()
    commandID1 = reaper.NamedCommandLookup("_b2ce30f0f372ec4995a64701ccb9169a")
    reaper.Main_OnCommand(commandID1, 0) -- Custom: ReaTrak Set to Count-In
    end

function btn_click_intro_post_fill()
    commandID2 = reaper.NamedCommandLookup("_f7c5b3a543e08d43804cf4dbf3c1cef0")
    reaper.Main_OnCommand(commandID2, 0) -- Custom: ReaTrak Set to Intro Post Fill
    end
    
function btn_click_intro()
    commandID3 = reaper.NamedCommandLookup("_b6b4a8efc7c17e4293bd5b72e6617705")
    reaper.Main_OnCommand(commandID3, 0) -- Custom: ReaTrak Set to Intro
    end   
	    
function btn_click_intro_fill()
    commandID4 = reaper.NamedCommandLookup("_90d9c3359514c547af6790ca8994a692")
    reaper.Main_OnCommand(commandID4, 0) -- Custom: ReaTrak Set to Intro Fill
    end    

function btn_click_verse_post_fill()
    commandID5 = reaper.NamedCommandLookup("_RS2b5a09cb0f7181f5a9eb036c0a61cb04e11e1ba6")
    reaper.Main_OnCommand(commandID5, 0) -- Custom: ReaTrak Set to Verse Post Fill
    end

function btn_click_verse()
    commandID6 = reaper.NamedCommandLookup("_ee462747fde1024f9cbab032dc78f12a")
    reaper.Main_OnCommand(commandID6, 0) -- Custom: ReaTrak Set to Verse
    end

function btn_click_verse_fill()
    commandID7 = reaper.NamedCommandLookup("_705d2ad890997c47910db95a51711f24")
    reaper.Main_OnCommand(commandID7, 0) -- Custom: ReaTrak Set to Verse Fill
    end
    
function btn_click_verse_ending()
    commandID8 = reaper.NamedCommandLookup("_a8a68b8ec61b344493682802d9ac44a4")
    reaper.Main_OnCommand(commandID8, 0) -- Custom: ReaTrak Set to Ending Verse
    end 
	  
---Sections Row 2

function btn_click_bridge_post_fill()
    commandID9 = reaper.NamedCommandLookup("_34073107cc237b4f98d4c3dffd500c90")
    reaper.Main_OnCommand(commandID9, 0) -- Custom: ReaTrak Set to Bridge Post Fill
    end

function btn_click_bridge()
    commandID10 = reaper.NamedCommandLookup("_41fcba1bbfc22647825c27de49981278")
    reaper.Main_OnCommand(commandID10, 0) -- Custom: ReaTrak Set to Bridge
    end

local function btn_click_bridge_fill()
    commandID11 = reaper.NamedCommandLookup("_0760f57fdfe45641ba1da32b9e6155aa")
    reaper.Main_OnCommand(commandID11, 0) -- Custom: ReaTrak Set to Bridge Fill
    end
    
function btn_click_pre_chorus_post_fill()
    commandID12 = reaper.NamedCommandLookup("_RSa696c463f4a0acdae5833b6f42c72465350fdc40")
    reaper.Main_OnCommand(commandID12, 0) -- Custom: ReaTrak Set to Pre Chorus Post Fill
    end

function btn_click_pre_chorus()
    commandID13 = reaper.NamedCommandLookup("_RS889edadcc4c7ff0264ede8feedf3ea69dc714595")
    reaper.Main_OnCommand(commandID13, 0) -- Custom: ReaTrak Set to Pre Chorus
    end

function btn_click_pre_chorus_fill()
    commandID14 = reaper.NamedCommandLookup("_RS8ae2b25083efeab5740bdcc7250ea42bb7d56125")
    reaper.Main_OnCommand(commandID14, 0) -- Custom: ReaTrak Set to Pre Chorus Fill
    end
    
function btn_click_chorus_post_fill()
    commandID15 = reaper.NamedCommandLookup("_9f3494ace8dc654ca2f8731d56fba4c4")
    reaper.Main_OnCommand(commandID15, 0) -- Custom: ReaTrak Set to Chorus Post Fill
    end

function btn_click_chorus()
    commandID16 = reaper.NamedCommandLookup("_11153a391144ba4c959ddd4915885bfd")
    reaper.Main_OnCommand(commandID16, 0) -- Custom: ReaTrak Set to Chorus
    end

function btn_click_chorus_fill()
    commandID17 = reaper.NamedCommandLookup("_226c876dff5f82488ad78626dfce652b")
    reaper.Main_OnCommand(commandID17, 0) -- Custom: ReaTrak Set to Chorus Fill
    end
    
function btn_click_chorus_ending()
    commandID18 = reaper.NamedCommandLookup("_f2f3a75e68c966459bdf4fa0460389a8")
    reaper.Main_OnCommand(commandID18, 0) -- Custom: ReaTrak Set to Ending Chorus
    end    
    
---Sections Row 3

function btn_click_rest()
    commandID22 = reaper.NamedCommandLookup("_c7b48c7e54f8e94f9f3437b58f81d549")
    reaper.Main_OnCommand(commandID22, 0) -- Custom: ReaTrak Set to Rest
    end

function btn_click_shot()
    commandID23 = reaper.NamedCommandLookup("_929e978567d96b439647f7437c867c86")
    reaper.Main_OnCommand(commandID23, 0) -- Custom: ReaTrak Set to Shot
    end
    
function btn_click_hold()
    commandID24 = reaper.NamedCommandLookup("_36088becd3ad3948b6d69148121ae590")
    reaper.Main_OnCommand(commandID24, 0) -- Custom: ReaTrak Set to Hold
    end    
    
    


--Tools Buttons

-- Sections
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x1 = 0
y1 = 0  



GUI.New("lb_Sect",      "Label",           3, 20+x1, 20+y1, "ReaTrak Sections", true, 1)

GUI.New("sect_help_btn",      "Button",           3, 225+x1, 32+y1, 40, 17, "HELP", btn_click_sect_help)
GUI.elms.sect_help_btn.col_txt = "btn_txt1"
GUI.elms.sect_help_btn.col_fill = "green"
GUI.elms.sect_help_btn.font = ("version")

GUI.New("lb_Sect_info",      "Label",           3, 285+x1, 32+y1, "set the chord region to the song section", true, 3)

--Label          name,      z,      x,      y,          caption[, shadow, font, color, bg]
os_type = reaper.GetOS()
poz = 655 font_type = "i" font_size = 56
if os_type ~= "Win32" and os_type ~= "Win64" then poz = 670 font_type = "r" font_size = 56 end


GUI.New("lb_reatrack",      "Label",           3, poz+x1, 5+y1, "ReaTrak", true, 1, "verse_fill", "wnd_bg" )
GUI.elms.lb_reatrack.col_txt = "verse_fill"
--GUI.elms.lb_reatrack.font = {"Impact", font_size, font_type}
GUI.elms.lb_reatrack.font = {"LeagueGothic-CondensedItalic", font_size, font_type}

GUI.New("lb_studio",      "Label",           3, 734+x1, 17+y1, "Studio", true, 1, "white", "wnd_bg" )
GUI.elms.lb_studio.col_txt = "verse_fill"
GUI.elms.lb_studio.font = {"Arial", 40, "bi"}


GUI.New("count_in_btn",      "Button",           3, 16+x1, 65+y1, 70, 20, "Count-In", btn_click_count_in)
GUI.elms.count_in_btn.col_txt = "btn_txt3"
GUI.elms.count_in_btn.col_fill = "count_in" 

GUI.New("intro_post_fill_btn",      "Button",           3, 90+x1, 65+y1, 95, 20, "Intro Post Fill", btn_click_intro_post_fill)
GUI.elms.intro_post_fill_btn.col_txt = "btn_txt1"
GUI.elms.intro_post_fill_btn.col_fill = "intro_post_fill" 

GUI.New("intro_btn",      "Button",           3, 190+x1, 65+y1, 60, 20, "Intro", btn_click_intro)
GUI.elms.intro_btn.col_txt = "btn_txt1"
GUI.elms.intro_btn.col_fill = "intro"

GUI.New("intro_fill_btn",      "Button",           3, 255+x1, 65+y1, 60, 20, "Intro Fill", btn_click_intro_fill)
GUI.elms.intro_fill_btn.col_txt = "btn_txt3"
GUI.elms.intro_fill_btn.col_fill = "intro_fill"

GUI.New("verse_post_fill_btn",      "Button",           3, 320+x1, 65+y1, 95, 20, "Verse Post Fill", btn_click_verse_post_fill)
GUI.elms.verse_post_fill_btn.col_txt = "btn_txt1"
GUI.elms.verse_post_fill_btn.col_fill = "verse_post_fill"

GUI.New("verse_btn",      "Button",           3, 420+x1, 65+y1, 65, 20, "Verse", btn_click_verse)
GUI.elms.verse_btn.col_txt = "btn_txt1"
GUI.elms.verse_btn.col_fill = "verse"

GUI.New("verse_fill_btn",      "Button",           3, 490+x1, 65+y1, 70, 20, "Verse Fill", btn_click_verse_fill)
GUI.elms.verse_fill_btn.col_txt = "btn_txt3"
GUI.elms.verse_fill_btn.col_fill = "verse_fill"

GUI.New("verse_ending_btn",      "Button",           3, 565+x1, 65+y1, 90, 20, "Verse Ending ", btn_click_verse_ending)
GUI.elms.verse_ending_btn.col_txt = "btn_txt3"
GUI.elms.verse_ending_btn.col_fill = "verse_ending"

GUI.New("drum_riff_btn1",      "Button",           3, 660+x1, 65+y1, 75, 20, "Drum Riff", btn_click_set_drum_riff)
GUI.elms.drum_riff_btn1.col_txt = "btn_txt1"
GUI.elms.drum_riff_btn1.col_fill = "drum_riff"

-- Sections Row 2
 
GUI.New("bridge_post_fill_btn",      "Button",           3, 16+x1, 95+y1, 95, 20, "Bridge Post Fill", btn_click_bridge_post_fill)
GUI.elms.bridge_post_fill_btn.col_txt = "btn_txt1"
GUI.elms.bridge_post_fill_btn.col_fill = "bridge_post_fill" 

GUI.New("bridge_btn",      "Button",           3, 115+x1, 95+y1, 60, 20, "Bridge", btn_click_bridge)
GUI.elms.bridge_btn.col_txt = "btn_txt3"
GUI.elms.bridge_btn.col_fill = "bridge"

GUI.New("bridge_fill_btn",      "Button",           3, 180+x1, 95+y1, 70, 20, "Bridge Fill", btn_click_bridge_fill)
GUI.elms.bridge_fill_btn.col_txt = "btn_txt3"
GUI.elms.bridge_fill_btn.col_fill = "bridge_fill"

GUI.New("pre_chorus_post_fill_btn",      "Button",           3, 255+x1, 95+y1, 115, 20, "Pre Chorus Post Fill", btn_click_pre_chorus_post_fill)
GUI.elms.pre_chorus_post_fill_btn.col_txt = "btn_txt3"
GUI.elms.pre_chorus_post_fill_btn.col_fill = "pre_chorus_post_fill"

GUI.New("pre_chorus_btn",      "Button",           3, 375+x1, 95+y1, 75, 20, "Pre Chorus", btn_click_pre_chorus)
GUI.elms.pre_chorus_btn.col_txt = "btn_txt3"
GUI.elms.pre_chorus_btn.col_fill = "pre_chorus"

GUI.New("pre_chorus_fill_btn",      "Button",           3, 455+x1, 95+y1, 95, 20, "Pre Chorus Fill", btn_click_pre_chorus_fill)
GUI.elms.pre_chorus_fill_btn.col_txt = "btn_txt3"
GUI.elms.pre_chorus_fill_btn.col_fill = "pre_chorus_fill"

GUI.New("chorus_post_fill_btn",      "Button",           3, 555+x1, 95+y1, 95, 20, "Chorus Post Fill", btn_click_chorus_post_fill)
GUI.elms.chorus_post_fill_btn.col_txt = "btn_txt1"
GUI.elms.chorus_post_fill_btn.col_fill = "chorus_post_fill"
GUI.New("chorus_btn",      "Button",           3, 655+x1, 95+y1, 55, 20, "Chorus", btn_click_chorus)
GUI.elms.chorus_btn.col_txt = "btn_txt1"
GUI.elms.chorus_btn.col_fill = "chorus"

GUI.New("chorus_fill_btn",      "Button",           3, 715+x1, 95+y1, 70, 20, "Chorus Fill", btn_click_chorus_fill)
GUI.elms.chorus_fill_btn.col_txt = "btn_txt3"
GUI.elms.chorus_fill_btn.col_fill = "chorus_fill"

GUI.New("chorus_ending_btn",      "Button",           3, 790+x1, 95+y1, 90, 20, "Chorus Ending ", btn_click_chorus_ending)
GUI.elms.chorus_ending_btn.col_txt = "btn_txt3"
GUI.elms.chorus_ending_btn.col_fill = "chorus_ending"

-- Sections Row 2


GUI.New("rest_btn",      "Button",           3, 375+x1, 125+y1, 40, 20, "Rest", btn_click_rest)
GUI.elms.rest_btn.col_txt = "btn_txt1"
GUI.elms.rest_btn.col_fill = "rest"

GUI.New("shot_btn",      "Button",           3, 420+x1, 125+y1, 40, 20, "Shot", btn_click_shot)
GUI.elms.shot_btn.col_txt = "btn_txt1"
GUI.elms.shot_btn.col_fill = "shot"

GUI.New("hold_btn",      "Button",           3, 465+x1, 125+y1, 40, 20, "Hold", btn_click_hold)
GUI.elms.hold_btn.col_txt = "btn_txt3"
GUI.elms.hold_btn.col_fill = "hold"

GUI.New("btn_frm",     "Frame",          3, 0, 156, GUI.w, 4, true, true)


--ReaTrak Actions Functions


function btn_click_act_help()
    commandID30 = reaper.NamedCommandLookup("_RSc8cc178fa82743e63c0937889c5d21f018f89025")
    reaper.Main_OnCommand(commandID30, 0) -- Script: ReaTrak actions help.lua
    end
    
function btn_click_show_chords_in_items()
    reaper.Main_OnCommand(40691, 0) -- View: Toggle show media cues in items
	  
    update_show_chords_in_items()
    end 
    
function btn_click_arranger()
    commandID44 = reaper.NamedCommandLookup("_S&M_SHOW_RGN_PLAYLIST")
    reaper.Main_OnCommand(commandID44, 0) -- SWS/S&M: Open/close Region Playlist window
    end       
    
function btn_click_choose_instrument()
    commandID31 = reaper.NamedCommandLookup("_affc9a3267b5384da92c67a48aeb8998")
    reaper.Main_OnCommand(commandID31, 0) -- Custom: ReaTrak Choose Instrument
    end    

function btn_click_reatrak()
    commandID32 = reaper.NamedCommandLookup("_dc512c9369370044a2f8a292c27ca39d")
    reaper.Main_OnCommand(commandID32, 0) -- Custom: ReaTrak
    end    

function btn_click_reatrak_selection()
    commandID33 = reaper.NamedCommandLookup("_0aaf7120a177a044b41d609683934470")
    reaper.Main_OnCommand(commandID33, 0) -- Custom: ReaTrak Selection
    end    

function btn_click_redo_selection()
    commandID34 = reaper.NamedCommandLookup("_0aaf7120a177a044b41d609683934470")
    reaper.Main_OnCommand(commandID34, 0) -- Custom: ReaTrak Redo Selection
    end    

function btn_click_midi_natation()
    commandID35 = reaper.NamedCommandLookup("_243882a556b4a24390679255a508233c")
    reaper.Main_OnCommand(commandID35, 0) -- Custom: ReaTrak Get MIDI Notation for Audio from mid file
    end    

function btn_click_import_chords()
    reaper.Main_OnCommand(41759, 0) -- Markers/Regions: Import markers/regions from file (replace all existing)
    end   

function btn_click_midi_chord_track()
    commandID36 = reaper.NamedCommandLookup("_8f65d65ed51ecf4c947500e10cc72333")
    reaper.Main_OnCommand(commandID36, 0) -- Custom: ReaTrak Create MIDI Chords from Region Chord name
    end   

function btn_click_decay_fill_2bars2()
    commandID37 = reaper.NamedCommandLookup("_RS5bc5e3f22e0523c58534ef3d3c38cee3a974262c")
    reaper.Main_OnCommand(commandID37, 0) -- Script: ReaTrak lengthen selected item by 2 bars.lua
    end    
    
function btn_click_musicxml_chords()
    commandID37 = reaper.NamedCommandLookup("_RS375dbf0f2902e41294d13434abfc48e46e54a560")
    reaper.Main_OnCommand(commandID37, 0) -- Script: ReaTrak musicxml chords notation events to regions.lua
    end    

function btn_click_chords_from_midi_markers()
    commandID38 = reaper.NamedCommandLookup("_6d6a7a1f3903ce468e1d09422f81ea08")
    reaper.Main_OnCommand(commandID38, 0) -- Custom: ReaTrak Import Chord Markers from MIDI Track to Regions
    end    

function btn_click_chords_from_midi_lyrics()
    commandID39 = reaper.NamedCommandLookup("_RS583f37fc5569edab89f5b140ae2a67f85f2f1218")
    reaper.Main_OnCommand(commandID39, 0) -- Script: ReaTrak add regions from midi lyrics selected items.lua
    end    

function btn_click_text_chord_track()
    commandID41 = reaper.NamedCommandLookup("_25a40d32e8a51e4490f20d848e204f44")
    reaper.Main_OnCommand(commandID40, 0) -- Custom: ReaTrak Track Text Chords
    end

function btn_biab_drums()
    commandID42 = reaper.NamedCommandLookup("_RS6c08e9df64c8bae1935a9ff8f2b237688090b305")
    reaper.Main_OnCommand(commandID42, 0) -- Script: ReaTrak biab drums.lua
    end        

function btn_click_snap_midi_to_chords()
    commandID43 = reaper.NamedCommandLookup("_RSe5a47e6b8b345105272f6eeec66bd1f1e1c43892")
    reaper.Main_OnCommand(commandID43, 0) -- Script: ReaTrak snap midi takes to chords.lua
    end

function btn_click_drum_riff_selection()
    commandID19 = reaper.NamedCommandLookup("_cd48802cf959d24899b5fd6375d9e202")
    reaper.Main_OnCommand(commandID19, 0) -- Custom: ReaTrak Drum Riff Selection
    end

function btn_click_redo_drum_riff()
    commandID20 = reaper.NamedCommandLookup("_94bf61335e356940ba7c7133e0157412")
    reaper.Main_OnCommand(commandID20, 0) -- Custom: ReaTrak Redo Drum Riff
    end
    
function btn_click_remove_drum_riff()
    commandID21 = reaper.NamedCommandLookup("_84f0ef8db34384428d97be197f4bf540")
    reaper.Main_OnCommand(commandID21, 0) -- Custom: ReaTrak Remove Drum Riff
    end
    
function btn_click_decay_all_D_on_track()
    commandID22 = reaper.NamedCommandLookup("_RSe58c776d6645bdbe9fd063dd48c2f8d699e11591")
    reaper.Main_OnCommand(commandID22, 0) -- Script: ReaTrak decay all -D items on track.lua
    end

function btn_click_circle_of_fifths()
    commandID23 = reaper.NamedCommandLookup("_RS5c33378c0bda081e673d359fd650ee9c540e531a")
    reaper.Main_OnCommand(commandID23, 0) -- Script: ReaTrak Circle of Fifths Menu.lua
    end    
	   



--ReaTrak Actions
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x2 = 0
y2 = 0  

GUI.New("lb_rea_act",      "Label",           3, 20+x2, 170+y2, "ReaTrak Actions", true, 1)

GUI.New("act_help_btn",      "Button",           3, 215+x1, 180+y1, 40, 17, "HELP", btn_click_act_help)
GUI.elms.act_help_btn.col_txt = "btn_txt1"
GUI.elms.act_help_btn.col_fill = "green"
GUI.elms.act_help_btn.font = ("version")


function update_show_chords_in_items() 
	  
--Delete old buttons before updating  

   if reaper.GetToggleCommandState(40691) == 1 then onstate = "black" textstate = "red"
   else
	 onstate = "gray" textstate = "yellow"
   end
GUI.elms.show_chords_in_items_btn:ondelete()
 
GUI.New("show_chords_in_items_btn",      "Button",           3, 275+x1, 180+y1, 135, 20, "Show Chords in Items", btn_click_show_chords_in_items)
GUI.elms.show_chords_in_items_btn.col_txt = textstate
GUI.elms.show_chords_in_items_btn.col_fill = onstate    

GUI.elms.show_chords_in_items_btn:init()    

end



   if reaper.GetToggleCommandState(40691) == 1 then onstate = "black" textstate = "red"
   else
	 onstate = "gray" textstate = "yellow"
   end
   
GUI.New("arranger_btn",      "Button",           3, 415+x1, 180+y1, 75, 20, "Arranger", btn_click_arranger)
GUI.elms.arranger_btn.col_txt = "yellow"
GUI.elms.arranger_btn.col_fill = "gray"    
	 
GUI.New("show_chords_in_items_btn",      "Button",           3, 275+x1, 180+y1, 135, 20, "Show Chords in Items", btn_click_show_chords_in_items)
GUI.elms.show_chords_in_items_btn.col_txt = textstate
GUI.elms.show_chords_in_items_btn.col_fill = onstate
 
GUI.New("choose_instrument_btn",      "Button",           3, 16+x2, 215+y2, 115, 20, "Choose Instrument", btn_click_choose_instrument)
GUI.elms.choose_instrument_btn.col_txt = "yellow"
GUI.elms.choose_instrument_btn.col_fill = "gray" 

GUI.New("reatrak_btn",      "Button",           3, 135+x2, 215+y2, 70, 20, "ReaTrak", btn_click_reatrak)
GUI.elms.reatrak_btn.col_txt = "yellow"
GUI.elms.reatrak_btn.col_fill = "gray" 

GUI.New("reatrak_selection_btn",      "Button",           3, 209+x2, 215+y2, 115, 20, "ReaTrak Selection", btn_click_reatrak_selection)
GUI.elms.reatrak_selection_btn.col_txt = "yellow"
GUI.elms.reatrak_selection_btn.col_fill = "gray" 

GUI.New("redo_selection_btn",      "Button",           3, 328+x2, 215+y2, 115, 20, "Redo Selection", btn_click_redo_selection)
GUI.elms.redo_selection_btn.col_txt = "yellow"
GUI.elms.redo_selection_btn.col_fill = "gray"

GUI.New("midi_natation_btn",      "Button",           3, 447+x2, 215+y2, 115, 20, "MIDI Notation", btn_click_midi_natation)
GUI.elms.midi_natation_btn.col_txt = "yellow"
GUI.elms.midi_natation_btn.col_fill = "gray"

GUI.New("import_chords2_btn",      "Button",           3, 566+x2, 215+y2, 115, 20, "Import Chords", btn_click_import_chords)
GUI.elms.import_chords2_btn.col_txt = "yellow"
GUI.elms.import_chords2_btn.col_fill = "gray"

GUI.New("midi_chord_track_btn",      "Button",           3, 685+x2, 215+y2, 115, 20, "MIDI Chord Track", btn_click_midi_chord_track)
GUI.elms.midi_chord_track_btn.col_txt = "yellow"
GUI.elms.midi_chord_track_btn.col_fill = "gray"

GUI.New("decay_fill_2bars2_btn",      "Button",           3, 805+x2, 215+y2, 105, 20, "Decay Fill 2 bars", btn_click_decay_fill_2bars2)
GUI.elms.decay_fill_2bars2_btn.col_txt = "yellow"
GUI.elms.decay_fill_2bars2_btn.col_fill = "gray"

--Actions Row 2

GUI.New("musicxml_chords_btn",      "Button",           3, 16+x2, 245+y2, 145, 20, "Chords from MusicXML", btn_click_musicxml_chords)
GUI.elms.musicxml_chords_btn.col_txt = "yellow"
GUI.elms.musicxml_chords_btn.col_fill = "gray"

GUI.New("chords_from_midi_markers_btn",      "Button",           3, 166+x2, 245+y2, 165, 20, "Chords from MIDI Markers", btn_click_chords_from_midi_markers)
GUI.elms.chords_from_midi_markers_btn.col_txt = "yellow"
GUI.elms.chords_from_midi_markers_btn.col_fill = "gray"

GUI.New("chords_from_midi_lyrics_btn",      "Button",           3, 336+x2, 245+y2, 165, 20, "Chords from MIDI Lyrics", btn_click_chords_from_midi_lyrics)
GUI.elms.chords_from_midi_lyrics_btn.col_txt = "yellow"
GUI.elms.chords_from_midi_lyrics_btn.col_fill = "gray"

GUI.New("text_chord_track_btn",      "Button",           3, 506+x2, 245+y2, 125, 20, "Text Chord Track", btn_click_text_chord_track)
GUI.elms.text_chord_track_btn.col_txt = "yellow"
GUI.elms.text_chord_track_btn.col_fill = "gray"

GUI.New("biab_drums_btn",      "Button",           3, 636+x2, 245+y2, 95, 20, "Biab Drums", btn_click_biab_drums)
GUI.elms.biab_drums_btn.col_txt = "yellow"
GUI.elms.biab_drums_btn.col_fill = "gray"

GUI.New("snap_midi_to_chords_btn",      "Button",           3, 736+x2, 245+y2, 135, 20, "Snap MIDI to Chords", btn_click_snap_midi_to_chords)
GUI.elms.snap_midi_to_chords_btn.col_txt = "yellow"
GUI.elms.snap_midi_to_chords_btn.col_fill = "gray"

--Actions Row 3

GUI.New("drum_riff_selection_btn",      "Button",           3, 16+x1, 275+y1, 115, 20, "Drum Riff Selection", btn_click_drum_riff_selection)
GUI.elms.drum_riff_selection_btn.col_txt = "btn_txt1"
GUI.elms.drum_riff_selection_btn.col_fill = "drum_riff" 

GUI.New("redo_drum_riff_btn",      "Button",           3, 135+x1, 275+y1, 115, 20, "Redo Drum Riff", btn_click_redo_drum_riff)
GUI.elms.redo_drum_riff_btn.col_txt = "btn_txt1"
GUI.elms.redo_drum_riff_btn.col_fill = "drum_riff"

GUI.New("remove_drum_riff_btn",      "Button",           3, 255+x1, 275+y1, 115, 20, "Remove Drum Riff", btn_click_remove_drum_riff)
GUI.elms.remove_drum_riff_btn.col_txt = "btn_txt1"
GUI.elms.remove_drum_riff_btn.col_fill = "drum_riff"

GUI.New("decay_all_D_on_track_btn",      "Button",           3, 375+x1, 275+y1, 125, 20, "Decay all -D on Track", btn_click_decay_all_D_on_track)
GUI.elms.decay_all_D_on_track_btn.col_txt = "yellow"
GUI.elms.decay_all_D_on_track_btn.col_fill = "gray"

GUI.New("circle_of_fifths_btn",      "Button",           3, 505+x1, 275+y1, 100, 20, "Circle of Fifths", btn_click_circle_of_fifths)
GUI.elms.circle_of_fifths_btn.col_txt = "yellow"
GUI.elms.circle_of_fifths_btn.col_fill = "gray"



GUI.New("btn_frm2",     "Frame",          3, 0, 320, GUI.w, 4, true, true)





--ReaTrak Edit Functions

function btn_click_edit_help()
    commandID51 = reaper.NamedCommandLookup("_RS68073fe0041179348e0fb6f7d0f85e85f1b9c3a4")
    reaper.Main_OnCommand(commandID51, 0) -- Script: ReaTrak edit help.lua
    end
    
function btn_click_insert_chord()
    commandID52 = reaper.NamedCommandLookup("_4190cb5a012a9a4db06a253f79f13a85")
    reaper.Main_OnCommand(commandID52, 0) -- Custom: ReaTrak Insert Chord
    end

function btn_click_insert_chord_selection()
    reaper.Main_OnCommand(40306, 0) -- Markers: Insert region from time selection and edit
    end 

function btn_click_edit_chord()
    reaper.Main_OnCommand(40616, 0) -- Markers: Edit region near cursor
    end    
	    
function btn_click_split_chord_region()
    commandID53 = reaper.NamedCommandLookup("_RS8fa94cd55cd82c3d9b0a066f7f5ceec2009c7180")
    reaper.Main_OnCommand(commandID53, 0) -- Script: ReaTrak Split region under cursor.eel
    end

function btn_click_chord_regions()
    reaper.Main_OnCommand(40326, 0) -- View: Show region/marker manager window
    end    

function btn_click_snap_chords_grid()
    commandID54 = reaper.NamedCommandLookup("_RS0b4230c08f384a4318c16aac4e2404c9fef86887")
    reaper.Main_OnCommand(commandID54, 0) -- Script: ReaTrak Snap all regions to grid.eel
    end
	
function btn_click_transpose_chords()
    commandID55 = reaper.NamedCommandLookup("_RS243506a4ece5cd8f1050d89c241baaee2b286a15")
    reaper.Main_OnCommand(commandID55, 0) -- Script: ReaTrak transpose chords selection.lua
    end
	
function btn_click_insert_bars()
    commandID56 = reaper.NamedCommandLookup("_cb76e351ba62ac4c8da62b1d7432f521")
    reaper.Main_OnCommand(commandID56, 0) -- Custom: ReaTrak Insert Bars
    end
	
function btn_click_remove_bars()
    commandID57 = reaper.NamedCommandLookup("_e7fa1c6be44c19409e56de09357c6889")
    reaper.Main_OnCommand(commandID57, 0) -- Custom: ReaTrak Remove Bars
    end
	
function btn_click_copy_chords()
    commandID58 = reaper.NamedCommandLookup("_RS86c331d8ad1119ad855aa6311d9116aa8d22a6dd")
    reaper.Main_OnCommand(commandID58, 0) -- Script: ReaTrak Copy project markers and regions in time selection.lua
    end
	
function btn_click_paste_chords()
    commandID59 = reaper.NamedCommandLookup("_28e11f451e11d3408dcc9339c74ea29f")
    reaper.Main_OnCommand(commandID59, 0) -- Custom: ReaTrak Paste Insert Regions Markers
    end
	
function btn_click_glue_track()
    commandID60 = reaper.NamedCommandLookup("_5e8c07d444b762489b550bdfd7f8ed39")
    reaper.Main_OnCommand(commandID60, 0) -- Custom: ReaTrak Glue Track Items
    end

function btn_click_export_chords()
    commandID61 = reaper.NamedCommandLookup("_456b491816ecba44932ec63ea5e3faed")
    reaper.Main_OnCommand(commandID61, 0) -- Custom: ReaTrak Export Chords
    end    

function btn_click_export_renumber_chords()
    commandID62 = reaper.NamedCommandLookup("_1d118cb7528a39459e792639d3501064")
	   reaper.Main_OnCommand(commandID62, 0) -- Custom: ReaTrak Export/Renumber Chords
    end
	    
function btn_click_decay_fill_2bars()
    commandID63 = reaper.NamedCommandLookup("_RS5bc5e3f22e0523c58534ef3d3c38cee3a974262c")
    reaper.Main_OnCommand(commandID63, 0) -- Script: ReaTrak lengthen selected item by 2 bars.lua
    end
    
function btn_click_remove_selected_crossfade()
    commandID64 = reaper.NamedCommandLookup("_eb97fc0933296c48a1ddfff48d6c3f22")
    reaper.Main_OnCommand(commandID64, 0) -- Custom: ReaTrak remove crossfade
    end 
    
function btn_click_remove_track_crossfades()
    commandID65 = reaper.NamedCommandLookup("_7bbc0eab6fc73c4b935e263650cbc3ce")
    reaper.Main_OnCommand(commandID65, 0) -- Custom: ReaTrak remove all crossfades from track
    end

function btn_click_selected_notes_to_chord_name()
    commandID66 = reaper.NamedCommandLookup("_RSc73f9a4ab45a0812b2d415c79ecf756f553b54ba")
    reaper.Main_OnCommand(commandID66, 0) -- Script: ReaTrak selected notes to chord name and reascale.lua
    end           
    
function btn_click_split_region_at_bars()
    commandID67 = reaper.NamedCommandLookup("_36b8e76821195744b46d4b5156f12182")
    reaper.Main_OnCommand(commandID67, 0) -- Custom: ReaTrak split region at bars
    end
    
function btn_click_split_region_at_beats()
    commandID68 = reaper.NamedCommandLookup("_b14cce354562434393ccddfa629158f8")
    reaper.Main_OnCommand(commandID68, 0) -- Custom: ReaTrak split region at beats
    end 
    
function btn_click_transpose_selected_items()
    commandID69 = reaper.NamedCommandLookup("_RSe421cdcd255a30db79468d6587813761466a9506")
    reaper.Main_OnCommand(commandID69, 0) -- Script: ReaTrak transpose selected items.lua
    end       
    
	 
    
    


--ReaTrak Edit
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x3 = 0
y3 = 0  

GUI.New("lb_rea_edit",      "Label",           3, 20+x3, 330+y3, "ReaTrak Edit", true, 1)

GUI.New("edit_help_btn",      "Button",           3, 180+x3, 340+y3, 40, 17, "HELP", btn_click_edit_help)
GUI.elms.edit_help_btn.col_txt = "btn_txt1"
GUI.elms.edit_help_btn.col_fill = "green"
GUI.elms.edit_help_btn.font = ("version")

GUI.New("insert_chord_btn",      "Button",           3, 16+x3, 375+y3, 95, 20, "Insert Chord", btn_click_insert_chord)
GUI.elms.insert_chord_btn.col_txt = "btn_txt3"
GUI.elms.insert_chord_btn.col_fill = "hold"

GUI.New("insert_chord_selection_btn",      "Button",           3, 116+x3, 375+y3, 150, 20, "Insert Chord in Selection", btn_click_insert_chord_selection)
GUI.elms.insert_chord_selection_btn.col_txt = "btn_txt3"
GUI.elms.insert_chord_selection_btn.col_fill = "hold"

GUI.New("edit_chord_btn",      "Button",           3, 270+x3, 375+y3, 70, 20, "Edit Chord", btn_click_edit_chord)
GUI.elms.edit_chord_btn.col_txt = "btn_txt3"
GUI.elms.edit_chord_btn.col_fill = "hold"

GUI.New("split_chord_region_btn",      "Button",           3, 343+x3, 375+y3, 115, 20, "Split Chord Region", btn_click_split_chord_region)
GUI.elms.split_chord_region_btn.col_txt = "btn_txt3"
GUI.elms.split_chord_region_btn.col_fill = "hold"

GUI.New("chord_regions_btn",      "Button",           3, 462+x3, 375+y3, 95, 20, "Chord Regions", btn_click_chord_regions)
GUI.elms.chord_regions_btn.col_txt = "btn_txt3"
GUI.elms.chord_regions_btn.col_fill = "hold"

GUI.New("snap_chords_grid_btn",      "Button",           3, 562+x3, 375+y3, 135, 20, "Snap Chords to Grid", btn_click_snap_chords_grid)
GUI.elms.snap_chords_grid_btn.col_txt = "btn_txt3"
GUI.elms.snap_chords_grid_btn.col_fill = "hold"

GUI.New("transpose_chords_btn",      "Button",           3, 702+x3, 375+y3, 165, 20, "Transpose Selected Chords", btn_click_transpose_chords)
GUI.elms.transpose_chords_btn.col_txt = "btn_txt3"
GUI.elms.transpose_chords_btn.col_fill = "hold"

--Reatrak Edit Row 2

GUI.New("insert_bars_btn",      "Button",           3, 16+x3, 405+y3, 150, 20, "Insert Bars in Selection", btn_click_insert_bars)
GUI.elms.insert_bars_btn.col_txt = "btn_txt3"
GUI.elms.insert_bars_btn.col_fill = "hold"

GUI.New("remove_bars_btn",      "Button",           3, 170+x3, 405+y3, 145, 20, "Remove Selected Bars", btn_click_remove_bars)
GUI.elms.remove_bars_btn.col_txt = "btn_txt3"
GUI.elms.remove_bars_btn.col_fill = "hold"

GUI.New("copy_chords_btn",      "Button",           3, 320+x3, 405+y3, 145, 20, "Copy Selected Chords >", btn_click_copy_chords)
GUI.elms.copy_chords_btn.col_txt = "btn_txt3"
GUI.elms.copy_chords_btn.col_fill = "hold"

GUI.New("paste_chords_btn",      "Button",           3, 470+x3, 405+y3, 185, 20, "> and Paste Chords at Cursor", btn_click_paste_chords)
GUI.elms.paste_chords_btn.col_txt = "btn_txt3"
GUI.elms.paste_chords_btn.col_fill = "hold"

GUI.New("glue_track_btn",      "Button",           3, 660+x3, 405+y3, 145, 20, "Glue Items in Track", btn_click_glue_track)
GUI.elms.glue_track_btn.col_txt = "btn_txt3"
GUI.elms.glue_track_btn.col_fill = "hold"

--Reatrak Edit Row 3

GUI.New("export_chords_btn",      "Button",           3, 16+x3, 435+y3, 95, 20, "Export Chords", btn_click_export_chords)
GUI.elms.export_chords_btn.col_txt = "btn_txt3"
GUI.elms.export_chords_btn.col_fill = "hold"

GUI.New("export_renumber_chords2_btn",      "Button",           3, 115+x3, 435+y3, 145, 20, "Export/Renumber Chords", btn_click_export_renumber_chords)
GUI.elms.export_renumber_chords2_btn.col_txt = "btn_txt3"
GUI.elms.export_renumber_chords2_btn.col_fill = "hold"

GUI.New("decay_fill_2bars_btn",      "Button",           3, 265+x3, 435+y3, 135, 20, "Decay Fill by 2 bars", btn_click_decay_fill_2bars)
GUI.elms.decay_fill_2bars_btn.col_txt = "btn_txt3"
GUI.elms.decay_fill_2bars_btn.col_fill = "hold"

GUI.New("remove_selected_crossfade_btn",      "Button",           3, 405+x3, 435+y3, 165, 20, "Remove Selected Crossfade", btn_click_remove_selected_crossfade)
GUI.elms.remove_selected_crossfade_btn.col_txt = "btn_txt3"
GUI.elms.remove_selected_crossfade_btn.col_fill = "hold"

GUI.New("remove_track_crossfades_btn",      "Button",           3, 575+x3, 435+y3, 155, 20, "Remove Track Crossfades", btn_click_remove_track_crossfades)
GUI.elms.remove_track_crossfades_btn.col_txt = "btn_txt3"
GUI.elms.remove_track_crossfades_btn.col_fill = "hold"

GUI.New("selected_notes_to_chord_name_btn",      "Button",           3, 735+x3, 435+y3, 175, 20, "Selected Notes to Chord Name", btn_click_selected_notes_to_chord_name)
GUI.elms.selected_notes_to_chord_name_btn.col_txt = "btn_txt3"
GUI.elms.selected_notes_to_chord_name_btn.col_fill = "hold"

GUI.New("split_region_at_bars_btn",      "Button",           3, 16+x3, 465+y3, 130, 20, "Split Region @ Bars", btn_click_split_region_at_bars)
GUI.elms.split_region_at_bars_btn.col_txt = "btn_txt3"
GUI.elms.split_region_at_bars_btn.col_fill = "hold"

GUI.New("split_region_at_beats_btn",      "Button",           3, 150+x3, 465+y3, 130, 20, "Split Region @ Beats", btn_click_split_region_at_beats)
GUI.elms.split_region_at_beats_btn.col_txt = "btn_txt3"
GUI.elms.split_region_at_beats_btn.col_fill = "hold"

GUI.New("transpose_selected_items_btn",      "Button",           3, 285+x3, 465+y3, 150, 20, "Transpose Selected Items", btn_click_transpose_selected_items)
GUI.elms.transpose_selected_items_btn.col_txt = "btn_txt3"
GUI.elms.transpose_selected_items_btn.col_fill = "hold"


GUI.New("btn_frm3",     "Frame",          3, 0, 490, GUI.w, 4, true, true)


--ReaTrak Development Functions

function btn_click_rea_devl_help()
    commandID70 = reaper.NamedCommandLookup("_RSbd3da65fa96aecedb5d4ec28fb293c8e73ed56fc")
    reaper.Main_OnCommand(commandID70, 0) -- Script: ReaTrak development help.lua
    end

function btn_click_set_drum_riff()
    commandID71 = reaper.NamedCommandLookup("_5e1fe04adc6fe64d92f8e19d2fb2f59f")
    reaper.Main_OnCommand(commandID71, 0) -- Custom: ReaTrak Set to Drum Riff
    end    

function btn_click_set_play_anywhere()
    commandID72 = reaper.NamedCommandLookup("_98f3c748ca7b214aa9a7a1f5644c2cd5")
    reaper.Main_OnCommand(commandID72, 0) -- Custom: ReaTrak Set to Play Anywhere
    end
    
function btn_click_set_to_decay1()
    commandID73 = reaper.NamedCommandLookup("_a0450467fcb72a48a75c77cf0d3cd925")
    reaper.Main_OnCommand(commandID73, 0) -- Custom: ReaTrak set to decay 1 bar
    end        
    
function btn_click_set_to_decay2()
    commandID76 = reaper.NamedCommandLookup("_323f3dd46b2d3f40b0f507e0046a4bb1")
    reaper.Main_OnCommand(commandID76, 0) -- Custom: ReaTrak set to decay
    end        

function btn_click_remove_set_to_decay()
    commandID74 = reaper.NamedCommandLookup("_aeead470bd831849b64fe54a572c935b")
    reaper.Main_OnCommand(commandID74, 0) -- Custom: ReaTrak remove set to decay
    end    

function btn_click_remove_linked()
    commandID75 = reaper.NamedCommandLookup("_e6b9cad8910e2a448e812ce62b961a5f")
    reaper.Main_OnCommand(commandID75, 0) -- Custom: ReaTrak remove linked
    end    


--ReaTrak Development
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x4 = 0
y4 = 0  

GUI.New("lb_rea_devl",      "Label",           3, 20+x4, 500+y4, "ReaTrak Development", true, 1)

GUI.New("rea_devl_help_btn",      "Button",           3, 285+x1, 510+y1, 40, 17, "HELP", btn_click_rea_devl_help)
GUI.elms.rea_devl_help_btn.col_txt = "btn_txt1"
GUI.elms.rea_devl_help_btn.col_fill = "green"
GUI.elms.rea_devl_help_btn.font = ("version")

GUI.New("lb_rea_devl_info",      "Label",           3, 340+x1, 510+y1, "create instrument and percussion reatraks", true, 3)

GUI.New("set_drum_riff_btn",      "Button",           3, 16+x4, 545+y4, 115, 20, "Set to Drum Riff", btn_click_set_drum_riff)
GUI.elms.set_drum_riff_btn.col_txt = "btn_txt1"
GUI.elms.set_drum_riff_btn.col_fill = "drum_riff"

GUI.New("set_play_anywhere_btn",      "Button",           3, 135+x4, 545+y4, 125, 20, "Set to Play Anywhere", btn_click_set_play_anywhere)
GUI.elms.set_play_anywhere_btn.col_txt = "btn_txt1"
GUI.elms.set_play_anywhere_btn.col_fill = "play_anywhere"

GUI.New("set_to_decay1_btn",      "Button",           3, 265+x4, 545+y4, 95, 20, "Set to Decay1", btn_click_set_to_decay1)
GUI.elms.set_to_decay1_btn.col_txt = "btn_txt1"
GUI.elms.set_to_decay1_btn.col_fill = "shot"

GUI.New("set_to_decay2_btn",      "Button",           3, 365+x4, 545+y4, 95, 20, "Set to Decay2", btn_click_set_to_decay2)
GUI.elms.set_to_decay2_btn.col_txt = "btn_txt1"
GUI.elms.set_to_decay2_btn.col_fill = "shot"

GUI.New("remove_set_to_decay_btn",      "Button",           3, 465+x4, 545+y4, 95, 20, "Remove Decay", btn_click_remove_set_to_decay)
GUI.elms.remove_set_to_decay_btn.col_txt = "btn_txt1"
GUI.elms.remove_set_to_decay_btn.col_fill = "shot"

GUI.New("import_chords_btn",      "Button",           3, 565+x4, 545+y4, 95, 20, "Import Chords", btn_click_import_chords)
GUI.elms.import_chords_btn.col_txt = "btn_txt1"
GUI.elms.import_chords_btn.col_fill = "shot"

GUI.New("set_linked_btn",      "Button",           3, 665+x4, 545+y4, 95, 20, "Set to Linked", btn_click_set_linked)
GUI.elms.set_linked_btn.col_txt = "btn_txt1"
GUI.elms.set_linked_btn.col_fill = "shot"

GUI.New("remove_linked_btn",      "Button",           3, 765+x4, 545+y4, 90, 20, "Remove Linked", btn_click_remove_linked)
GUI.elms.remove_linked_btn.col_txt = "btn_txt1"
GUI.elms.remove_linked_btn.col_fill = "shot"

GUI.New("export_renumber_chords_btn",      "Button",           3, 16+x4, 575+y4, 145, 20, "Export/Renumber Chords", btn_click_export_renumber_chords)
GUI.elms.export_renumber_chords_btn.col_txt = "btn_txt1"
GUI.elms.export_renumber_chords_btn.col_fill = "shot"

GUI.New("btn_frm4",     "Frame",          3, 0, 620, GUI.w, 4, true, true) 



---------------------------------------------------------------------
--Chord Scales Tab 2 (2,4)
---------------------------------------------------------------------

--Chord Input
--local number = GUI.Val("key_choice")

CMajor = {"C", "Dm", "Em", "F", "G", "Am", "Bdim", "CMaj7", "Dm7", "Em7", "FMaj7", "G7", "Am7", "Bm7b5"}
CsMajor = {"C#", "Ebm", "Fm", "F#", "G#", "A#m", "Cdim", "C#Maj7", "D#m7", "Fm7", "F#Maj7", "G#7", "A#m7", "Cm7b5"}
DbMajor = {"Db", " Ebm", " Fm", " Gb", "Ab", "Bbm", "Cdim", "DbMaj7", "Ebm7", "Fm7", "GbMaj7", "Ab7", " Bbm7", "Cm7b5"}
DMajor = {"D", "Em", "F#m", "G", "A", "Bm", "C#dim", "DMaj7", "Em7", "F#m7", "GMaj7", "A7", "Bm7", "C#m7b5"}
DsMajor = {"D#", "Fm", "Gm", "G#", "A#", "Cm", "Ddim", "D#Maj", "Fm7", "m7", "G#Maj7", "A7", "Cm7", "Dm7b5"}
EbMajor = {"Eb", "Fm", "Gm", "Ab", "Bb", "Cm", "Ddim", "EbMaj7", "Fm7", "Gm7", "AbMaj7", "Bb7", "Cm7", "Dm7b5"}
EMajor = {"E", "F#m", "G#m", "A", "B", "C#m", "D#dim", "EMaj7", "F#m7", "G#m7", "AMaj7", "B7", "C#m7", "D#m7b5"}
FMajor = {"F", "Gm", "Am", "Bb", "C", "Dm", "Edim", "FMaj7", "Gm7", "Am7", "BbMaj7", "C7", "Dm7", "Em7b5"}
FsMajor = {"F#", "G#m", "A#m", "B", "C#", "D#m", "Fdim", "F#maj7", "G#m7", "A#m7", "BMaj7", "C#7", "D#m7", "Fm7b5"}
GbMajor = {"Gb", "Abm", "Bbm", "B", "Db", "Ebm", "Fdim", "GbMaj7", "Abm7", "Bbm7", "BMaj7", "Db7", "Ebm7", "Fm7b5"}
GMajor = {"G", "Am", "Bm", "C", "D", "Em", "F#dim", "GMaj7", "Am7", "Bm7", "CMaj7", "D7", "Em7", "F#m7b5"}
GsMajor = {"G#", "A#m", "Cm", "C#", "D#", "Fm", "Gdim", "G#Maj7", "A#m7", "Cm7", "C#Maj7", "D#7", "Fm7", "Gm7b5"}
AbMajor = {"Ab", "Bbm", "Cm", "Db", "Eb", "Fm", "Gdim", "bMaj7", "Bbm7", "Cm7", "DbMaj7", "Eb7", "Fm7", "Gm7b5"}
AMajor = {"A", "Bm", "C#m", "D", "E", "F#m", "G#dim", "AMaj7", "Bm7", "C#m7", "DMaj7", "E7", "F#m7", "G#m7b5"}
AsMajor = {"A#", "Cm", "Dm", "D#", "F", "Gm", "Adim", "A#Maj7", "Cm7", "Dm7", "D#Maj7", "F7", "Gm7", "Am7b5"}
BbMajor = {"Bb", "Cm", "Dm", "Eb", "F", "Gm", "Adim", "BbMaj7", "Cm7", "Dm7", "EbMaj7", "F7", "Gm7", "Am7b5"}
BMajor = {"B", "C#m", "D#m", "E", "F#", "G#m", "A#dim", "BMaj7", "C#m7", "D#m7", "EMaj7", "F#7", "G#m7", "A#m7b5"}


CMinor = {"Cm", "Ddim", "Eb", "Fm", "Gm", "Ab", "Bb", "Cm7", "Dm7b5", "EbMa7", "Fm7", "Gm7", "AbMaj7", "Bm7"}
CsMinor = {"C#m", "D#m", "E", "F#m", "G#m", "A", "B", "C#m7", "D#m7b5", "EMaj7", "F#m7", "G#m7", "AMaj7", "B7"}
DbMinor = {"Dbm", "Ebdim", "E", "Gbm", "Abm", "A", "B", "Dbm7", "Ebm7b5", "EMaj7", "Gbm7", "Abm7", "AMaj7", "B7"}
DMinor = {"Dm", "Edim", "F", "Gm", "Am", "Bb", "C", "Dm7", "Em7b5", "FMaj7", "Gm7", "A7", "BbMaj7", "C7"}
DsMinor = {"D#m", "Fdim", "F#", "G#m", "A#m", "B", "C#", "D#m7", "Fm7b5", "F#Maj7", "G#m7", "A#m7", "BMaj7", "C#7"}
EbMinor = {"Ebm", "Fdim", "Gb", "Abm", "Bbm", "B", "Db", "Ebm7", "Fm7b5", "GbMaj7", "Abm7", "Bb7", "BMaj7", "Db7"}
EMinor = {"Em", "F#dim", "G", "Am", "Bm", "C", "D", "Em7", "F#m7b5", "GMaj7", "Am7", "B7", "CMaj7", "D7"}
FMinor = {"Fm", "F#dim", "Ab", "Bbm", "Cm", "Db", "Eb", "Fm7", "F#m7b5", "AbMaj7", "Bbm7", "C7", "DbMaj7", "Eb7"}
FsMinor = {"F#m", "G#dim", "A", "Bm", "C#m", "D", "E", "F#m7", "G#m7b5", "AMaj7", "Bm7", "C#m7", "DMaj7", "E7"}
GbMinor = {"Gbm", "Abdim", "A", "Bm", "Dbm", "D", "E", "Gbm7", "Abm7b5", "AMaj7", "Bm7", "Dbm7", "DMaj7", "E7"}
GMinor = {"Gm", "Adim", "Bb", "Cm", "Dm", "Eb", "F", "Gm7", "Am7b5", "BbMaj7", "Cm7", "Dm7", "EbMaj7", "F7"}
GsMinor = {"G#m", "A#dim", "B", "C#m", "D#m", "E", "F#", "G#m7", "A#m7b5", "BMaj7", "C#m7", "D#m7", "EMaj7", "F#7"}
AbMinor = {"Abm", "Bbdim", "B", "Dbm", "Ebm", "E", "Gb", "Abm7", "Bbm7b5", "BMaj7", "Dbm7", "Ebm7", "EMaj7", "Gb7"}
AMinor = {"Am", "Bdim", "C", "Dm", "Em", "F", "G", "Am7", "Bm7b5", "CMaj7", "Dm7", "E7", "FMaj7", "G7"}
AsMinor = {"A#m", "Cdim", "C#", "D#m", "Fm", "F#", "G#", "A#m7", "Cm7b5", "C#Maj7", "D#m7", "Fm7", "F#Maj7", "G#7"}
BbMinor = {"Bbm", "Cdim", "Db", "Ebm", "Fm", "Gb", "Ab", "Bbm7", "Cm7b5", "DbMaj7", "Ebm7", "Fm7", "GbMaj7", "Ab7"}
BMinor = {"Bm", "C#dim", "D", "Em", "F#m", "G", "A", "Bm7", "C#m7b5", "DMaj7", "Em7", "F#7", "GMaj7", "A7"}


CHarmonic_Major = {"C", "Ddim", "E", "Fm", "G", "Abdim", "Bdim", "CMaj7", "Dm7b5", "Em", "FmMaj7", "G7", "Abaug", "Bdim7"}
CsHarmonic_Major = {"C#", "D#dim", "F", "F#m", "  G#", "Adim", "Cdim", "C#Maj7", "D#m7b5", "Fm", "F#mMaj7", "G#7", "Aaug", "Cdim7"}
DbHarmonic_Major = {"Db", "Ebdim", "F", "Gbm", "Ab", "Adim", "Cdim", "DbMaj7", "Ebm7b5", "Fm", "GbmMaj7", "Ab7", "Aaug", "Cdim7"}
DHarmonic_Major = {"D", "Edim", "F#", "Gm", "A", "Bbdim", "Dbdim", "DMaj7", "Em7b5", "F#m", "GmMaj7", "A7", "Bbdim", "Dbdim7"}
DsHarmonic_Major = {"D#", "Fdim", "G", "G#m", "A#", "Bdim", "Ddim", "D#Maj7", "Fm7b5", "Gm", "G#mMaj7", "A#7", "Baug", "Ddim7"}
EbHarmonic_Major = {"Eb", "Fdim", "G", "Abm", "Bb", "Bdim", "Ddim", "EbMaj7", "Fm7b5", "Gm", "AbmMaj7", "Bb7", "Baug", "Ddim7"}
EHarmonic_Major = {"E", "F#dim", "Ab", "AmMaj7", "B", "Cdim", "Ebdim", "EMaj7", "F#m7b5", "Abm", "AmMaj7", "B7", "Caug", "Ebdim7"}
FHarmonic_Major = {"F", "Gdim", "A", " Bbm", "  C", " Dbdim", "Edim", " FMaj7", "Gm7b5", "Am", "BbmMaj7", "C7", "Dbaug", "Edim7"}
FsHarmonic_Major = {"F#", "G#dim", "A#", "Bm", "C#", "Ddim", "Fdim", "F#Maj7", "G#m7b5", "A#m", "BmMaj7", "C#7", "Daug", "Fdim7"}
GbHarmonic_Major = {"Gb", "Abdim", "Bb", "Bm", "Db", "Ddim", "Fdim", "GbMaj7", "Abm7b5", "Bbm", "BmMaj7", "Db7", "Daug", "Fdim7"}
GHarmonic_Major = {"G", "Adim", "B", "Cm", "D", "Ebdim", "F#dim", "GMaj7", "Am7b5", "Bm", "CmMaj7", "D7", "Ebaug", "F#dim7"}
GsHarmonic_Major = {"G#", "A#dim", "C", "C#m", "D#", "Edim", "Gdim", "G#Maj7", "A#m7b5", "Cm", "C#mMaj7", "D#7", "Eaug", "Gdim7"}
AbHarmonic_Major = {"Ab", "Bbdim", "C", "Dbm", "Eb", "Edim", "Gdim", "AbMaj7", "Bbm7b5", "Cm", "DbmMaj7", "Eb7", "Eaug", "Gdim7"}
AHarmonic_Major = {"A", "Bdim", "C#", "Dm", "E", "Fdim", "Abdim", "AMaj7", "Bm7b5", "Dbm", "DmMaj7", "E7", "Faug", "Abdim7"}
AsHarmonic_Major = {"A#", "Cdim", "D", "D#m", "F", "F#dim", "Adim", "A#Maj7", "Cm7b5", "Dm", "D#mMaj7", "F7", "F#aug", "Adim7"}
BbHarmonic_Major = {"Bb", "Cdim", "D", "Ebm", "F", "Gbdim", "Adim", " BbMaj7", "Cm7b5", "Dm", "EbmMaj7", "F7", "Gbaug", "Adim7"}
BHarmonic_Major = {"B", "C#dim", "Eb", "Em", "F#", "Gdim", "Bbdim", "BMaj7", "C#m7b5", "Ebm", "EmMaj7", "F#7", "Gaug", "Bbdim7"}

CMelodic_Major = {"C", "Ddim", "Edim", "Fm", "Gm", "Abaug", "Bb", "C7", "Dm7b5", "Eaug", "FmMaj7", "Gm7", "AbMaj7#5", "Bb7"}
CsMelodic_Major = { "C#", "D#dim", "Fdim", "F#m", "G#m", "Aaug", "B", "C#7", "D#m7b5", "Faug", "F#mMaj7", "G#m7", "AMaj7#5", "B7"}
DbMelodic_Major = { "Db", "Ebdim", "Fdim", "Gbm", "Abm", "Aaug", "B", "Db7", "Ebm7b5", "Faug", "GbmMaj7", "Abm7", "AMaj7#5", "B7"}
DMelodic_Major = { "D", "Edim", "Cbdim", "Gm", "Am", "Bbaug", "C", "D7", "Em7b5", "Gbaug", "GmMaj7", "Am7", "BbMaj7#5", "C7"}
DsMelodic_Major = { "D#", "Fdim", "Gdim", "G#m", "A#m", "Baug", "C#", "D#7", "Fm7b5", "Gaug", "G#mMaj7", "A#m7", "BMaj7#5", "C#7"}
EbMelodic_Major = { "Eb", "Fdim", "Gdim", "Abm", "Bbm", "Baug", "Db", "Eb7", "Fm7b5", "Gaug", "AbmMaj7", "Bbm7", "BMaj7#5", "Db7"}
EMelodic_Major = { "E", "Gbdim", "Abdim", "Am", "Bm", "Caug", "D", "E7", "Gb,7b5", "Abaug", "AnMaj7", "Bm7", "CMaj7#5", "D7"}
FMelodic_Major = { "F", "Gdim", "Adim", "Bbm", "Cm", "Dbaug", "Eb", "F7", "Gm7b5", "Aaug", "BbmMaj7", "Cm7", "DbMaj7#5", "Eb7"}
FsMelodic_Major = { "F#", "G#dim", "A#dim", "Bm", "C#m", "Daug", "E", "F#7", "G#m7b5", "A#aug", "BmMaj7", "C#m7", "DMaj7#5", "E7"}
GbMelodic_Major = { "Gb", "Abdim", "Bbdim", "Bm", "Dbm", "Daug", "E", "Gb7", "Abm7b5", "Bbaug", "BmMaj7", "Dbm7", "DMaj7#5", "E7"}
GMelodic_Major = { "G", "Adim", "Bdim", "Cm", "Dm", "Eaug", "F", "G7", "Am7b5", "Baug", "Cmmaj7", "Dm7", "EbMaj7#5", "F7"}
GsMelodic_Major = { "G#", "A#dim", "Cdim", "C#m", "D#m", "Eaug", "F#", "G#7", "A#m7b5", "Caug", "C#mMaj7", "D#m7", "EMaj7#5", "F#7"}
AbMelodic_Major = { "Ab", "Bbdim", "Cdim", "Dbm", "Ebm", "Eaug", "Gb", "Ab7", "Bbm7b5", "Caug", "DbmMaj7", "Ebm7", "EMaj7#5", "Gb7"}
AMelodic_Major = { "A", "Bdim", "Dbdim", "Dm", "Em", "Faug", "G", "A7", "Bm7b5", "Dbaug", "Dmmaj7", "Em7", "FMaj7#5", "G7"}
AsMelodic_Major = { "A#", "Cdim", "D#min", "D#m", "Fm", "F#aug", "G#", "A#7", "Cm7b5", "Daug", "D#mMaj7", "Fm7", "F#Maj7#5", "G#7"}
BbMelodic_Major = { "Bb", "Cdim", "Ddim", "Ebm", "Fm", "Gbaug", "Ab", "Bb7", "Cm7b5", "Daug", "EbmMaj7", "Fm7", "GbMaj7#5", "Ab7"}
BMelodic_Major = { "B", "Dbdim", "Ebdim", "Em", "Gbm", "Gaug", "A", "B7", "Dbm7b5", "Ebaug", "EmMaj7", "Gbm7", "GMaj7#5", "A7"}

CHarmonic_Minor = {"Cm", "Ddim", "Ebaug", "Fm", "G", "Ab", "Bdim", "CmMaj7", "Dm7b5", "EbMa7#5", "Fm7", "G7", "Abm", "Baug"}
CsHarmonic_Minor = {"C#m", "D#dim", "Eaug", "F#m", "G#", "A", "Cdim", "C#mMaj7", "D#m7b5", "EMaj7#5", "F#m7", "G#7", "Am", "Caug"}
DbHarmonic_Minor = {"Dbm", "Ebdim", "Eaug", "Gbm", "Ab", "A", "Cdim", "DbmMaj7", "Ebm7b5", "EMaj7#5", "Gbm7", "Ab7", "Am", "Caug"}
DHarmonic_Minor = {"Dm", "Edim", "Faug", "Gm", "A", "Bb", "Dbdim", "DmMaj7", "Em7b5", "FMaj7#", "Gm7", "A7", "Bbm", "Dbaug"}
DsHarmonic_Minor = {"D#m", "Fdim", "F#aug", "G#m", "A#", "B", "Ddim", "D#mMaj7", "Fm7b5", "F#Maj7#5", "G#m7", "A#7", "Bm", "Daug"}
EbHarmonic_Minor = {"Ebm", "Fdim", "Gbaug", "Abm", "Bb", "B", "Ddim", "EbmMaj7", "Fm7b5", "GbMaj7#5", "Abm7", "Bb7", "Bm", "Daug"}
EHarmonic_Minor = {"Em", "F#dim", "Gaug", "Am", "B", "C", "Ebdim", "EmMaj7", "F#m7b5", "GMaj7#5", "Am7", "B7", "Cm", "Ebdim7"}
FHarmonic_Minor = {"Fm", "Gdim", "Abaug", "Bbm", "C", "C#", "Edim", "FmMaj7", "Gm7b5", "AbMaj7#5", "Bbm7", "C7", "C#m", "Eaug"}
FsHarmonic_Minor = {"F#m", "G#dim", "Aaug", "Bm", "C#", "D", "Fdim", "F#mMaj7", "G#m7b5", "AMaj7#5", "Bm7", "C#7", "Dm", "Faug"}
GbHarmonic_Minor = {"Gbm", "Abdim", "Aaug", "Bm", "Db", "D", "Fdim", "GbmMaj7", "Abm7b5", "AMaj7#5", "Bm7", "Db7", "Dm", "Faug"}
GHarmonic_Minor = {"Gm", "Adim", "Bbaug", "Cm", "D", "Eb", "F#dim", "GmMaj7", "Am7b5", "BbMaj7#5", "Cm7", "D7", "Ebm", "F#aug"}
GsHarmonic_Minor = {"G#m", "A#dim", "Baug", "C#m", "D#", "E", "Gdim", "G#mMaj7", "A#m7b5", "BMaj7#5", "C#m7", "D#7", "Em", "Gaug"}
AbHarmonic_Minor = {"Abm", "Bbdim", "Baug", "Dbm", "Eb", "E", "Gdim", "AbmMaj7", "Bbm7b5", "BMaj7#5", "Dbm7", "Eb7", "Em", "Gaug"}
AHarmonic_Minor = {"Am", "Bdim", "Caug", "Dm", "E", "F", "G#dim", "AmMaj7", "Bm7b5", "CMaj7#5", "Dm7", "E7", "Fm", "G#aug"}
AsHarmonic_Minor = {"A#m", "Cdim", "C#aug", "D#m", "F", "F#", "Adim", "A#mMaj7", "Cm7b5", "C#Maj7#5", "D#m7", "F7", "F#m", "Aaug"}
BbHarmonic_Minor = {"Bbm", "Cdim", "Dbaug", "Ebm", "F", "Gb", "Adim", "BbmMaj7", "Cm7b5", "DbMaj7#5", "Ebm7", "F7", "Gbm", "Aaug"}
BHarmonic_Minor = {"Bm", "C#dim", "Daug", "Em", "F#", "G", "Bbdim", "BmMaj7", "C#m7b5", "DMaj7#5", "Em7", "F#7", "Gm", "Bbaug"}


CMelodic_Minor = {"Cm", "Dm", "Ebaug", "F", "G", "Adim", "Bdim", "CmMaj7", "Dm7", "EbMaj7#5", "F7", "G7", "Am7b5"}
CsMelodic_Minor = { "C#m", "D#m", "Eaug", "F#", "G#", "A#dim", "Cdim", "C#nMaj7", "D#m7", "EMaj7#5", "F#7", "G#7", "A#mb5", "Caug"}
DbMelodic_Minor = { "Dbm", "Em", "Eaug", "Gb", "Ab", "Bbdim", "Cdim", "DbmMaj7", "Ebm7", "EMaj7#5", "Gb7", "Ab7", "Bbm7b5", "Caug"}
DMelodic_Minor = { "Dm", "Em", "Faug", "G", "A", "Bdim", "Dbdim", "DmMaj7", "Em7", "FMa7#5", "G7", "A7", "Bm7b5", "Daug"}
DsMelodic_Minor = { "D#m", "Fm", "F#aug", "G#", "A#", "Cdim", "Ddim", "D#mMaj7", "Fm7", "F#Maj7#5", "G#7", "A#7", "Cm7b5", "Daug"}
EbMelodic_Minor = { "Ebm", "Fm", "Gbaug", "Ab", "Bb", "Cdim", "Ddim", "EbmMaj7", "Fm7", "GbMaj7#5", "Ab7", "Bb7", "Cm7b5", "Daug"}
EMelodic_Minor = { "Em", "Gbm", "Gaug", "A", "B", "Dbdim", "Ebdim", "EmMaj7", "Gbm7", "GMaj7#5", "A7", "B7", "Dbm7b5", "Ebaug"}
FMelodic_Minor = { "Fm", "Gm", "Abaug", "Bb", "C", "Ddim", "Edim", "FmMaj7", "Gm7", "AbMaj7#5", "Bb7", "C7", "Dm7b5", "Eaug"}
FsMelodic_Minor = { "F#m", "G#m", "Aaug", "B", "C#", "D#dim", "Fdim", "F#mMaj", "G#m7", "AMaj7#5", "B7", "C#7", "D#m7b5", "Faug"}
GbMelodic_Minor = { "Gbm", "Abm", "Aaug", "B", "Db", "Ebdim", "Fdim", "GbmMaj7", "Abm7", "AMaj7#5", "B7", "Db7", "Ebm7b5", "Faug"}
GMelodic_Minor = { "Gm", "Am", "Bbaug", "C", "D", "Edim", "Gbdim", "GmMaj7", "Am7", "BbMaj7#5", "C7", "D7", "Em7b5", "Gbaug"}
GsMelodic_Minor = { "G#m", "A#m", "Baug", "C#", "D#", "Fdim", "Gdim", "G#mMaj7", "A#m7", "BMaj7#5", "C#7", "D#7", "Fm7b5", "Gaug"}
AbMelodic_Minor = { "Abm", "Bbm", "Baug", "Db", "Eb", "Fdim", "Gdim", "AbmMaj7", "Bbm7", "BMaj7#5", "Db7", "Eb7", "Fm7b5", "Daug"}
AMelodic_Minor = { "Am", "Bm", "Caug", "D", "R", "Gbdim", "Abdim", "AmMaj7", "Bm7", "CMaj7#5", "D7", "E7", "Gbm7b5", "Abaug"}
AsMelodic_Minor = { "A#m", "Cm", "C#aug", "D#", "F", "Gdim", "Adim", "A#mMaj7", "Cm7", "C#Maj7#5", "D#7", "F7", "Gm7b5", "Aaug"}
BbMelodic_Minor = { "Bbm", "Cm", "Dbaug", "Eb", "F", "Gdim", "Adim", "BbmMaj7", "Cm7", "DbMaj7#5", "Eb7", "F7", "Gm7b5", "Aaug"}
BMelodic_Minor = { "Bm", "Dbm", "Daug", "E", "Gb", "Abdim", "Bbdim", "BmMaj7", "Dbm7", "DMaj7#5", "E7", "Gb7", "Abm7b5", "Bbaug"}

CIonian = {"C", "Dm", "Em", "F", "G", "Am", "Bdim", "CMaj7", "Dm7", "Em7", "FMaj7", "G7", "Am7", "Bm7b5"}
CsIonian = {"C#", "Ebm", "Fm", "F#", "Ab", "Bbm", "Cdim", "DbMaj7", "Eb7", "Fm7", "F#Maj7", "Ab7", "Bbm7", "Cm7b5"}
DbIonian = {"Db", "Ebm", "Fm", "F#", "Ab", "Bbm", "Cdim", "DbMaj7", "Eb7", "Fm7", "F#Maj7", "Ab7", "Bbm7", "Cm7b5"}
DIonian = {"D", "Em", "F#m", "G", "A", "Bm", "C#dim", "DMaj7", "Em7", "F#m7", "GMaj7", "A7", "Bm7", "C#m75m"}
DsIonian = {"D#", "Fm", "Gm", "G#", "Bb", "Cm", "Ddim", "D#Maj7", "Fm7", "Gm7", "G#Maj7", "Bb7", "Cm7", "Dm7b5"}
EbIonian = {"Eb", "Fm", "Gm", "G#", "Bb", "Cm", "Ddim", "D#Maj7", "Fm7", "Gm7", "G#Maj7", "Bb7", "Cm7", "Dm7b5"}
EIonian = {"E", "F#m", "G#m", "A", "B", "C#m", "Ebdim", "EMaj7", "F#m7", "G#m7", "AMaj7", "C#7", "D#m7b5"}
FIonian = {"F", "Gm", "Am", "Bb", "C", "Dm", "Edim", "FMaj7", "Gm7", "Am7", "BbMaj7", "C7", "Dm7", "Em7b5"}
FsIonian = {"F#", "G#m", "Bbm", "B", "C#", "Ebm", "Fdim", "F#Maj7", "G#m7", "Bbm7", "BMaj7", "C#7", "Ebm7"}
GbIonian = {"Gb", "G#m", "Bbm", "B", "C#", "Ebm", "Fdim", "GbMaj7", "G#m7", "Bbm7", "BMaj7", "C#7", "Ebm7"}
GIonian = {"G", "A", "Bm", "C", "D", "Em", "F#dim", "GMaj7", "Am7", "Bm7", "CMaj7", "D7", "Em7", "F#m7b5"}
GsIonian = {"G#", "A#m", "Cm", "C#", "Eb", "Fm", "Gdim", "G#Maj7", "Bbm7", "Cm7", "C#Maj7", "D#7", "Fm7", "Gm7b5"}
AbIonian = {"Ab", "A#m", "Cm", "C#", "Eb", "Fm", "Gdim", "AbMaj7", "Bbm7", "Cm7", "C#Maj7", "D#7", "Fm7", "Gm7b5"}
AIonian = {"A", "Bm", "C#m", "D", "E", "F#m", "G#dim", "AMaj7", "Bm7", "C#m7", "DMaj7", "E7", "F#m7", "G#m7b5"}
AsIonian = {"A#", "Cm", "Dm", "Eb", "F", "Gm", "Adim", "A#Maj7", "Cm7", "Dm7", "EbMaj7", "F7", "Gm7", "Am7b5"}
BbIonian = {"Bb", "Cm", "Dm", "Eb", "F", "Gm", "Adim", "BbMaj7", "Cm7", "Dm7", "EbMaj7", "F7", "Gm7", "Am7b5"}
BIonian = {"B", "C#m", "Ebm", "E", "F#", "G#m", "Bbdim", "BMaj7", "C#m7", "Ebm7", "EMaj7", "F#7", "G#m7", "Bbm7b5"}


CDorian = {"Cm", "Dm", "Eb", "F", "Gm", "Adim", "Bb", "Cm7", "Dm7", "EbMaj7", "F7", "Gm7", "Am7b5", "BbMaj7"}
CsDorian = {"C#m", "Ebm", "E", "F#", "G#", "Bbdim", "B", "C#m7", "Ebm7", "E#Maj7", "F#7", "G#m7", "Bbm7b5", "BMaj7"}
DbDorian = {"Dbm", "Ebm", "E", "F#", "G#", "Bbdim", "B", "Dbm7", "Ebm7", "E#Maj7", "F#7", "G#m7", "Bbm7b5", "BMaj7"}
DDorian = {"Dm", "Em", "F", "G", "Am", "Bdim", "C", "Dm7", "Em7", "FMaj7", "G7", "Am7", "Bm7b5", "CMaj7"}
DsDorian = {"D#m", "Fm", "F3", "G#", "Bbm", "Cdim", "C#", "D#m7", "Fm7", "F#Maj7", "G#7", "Bbm7", "Cm7b5", "C#Maj7"}
EbDorian = {"Ebm", "Fm", "F3", "G#", "Bbm", "Cdim", "C#", "Ebm7", "Fm7", "F#Maj7", "G#7", "Bbm7", "Cm7b5", "C#Maj7"}
EDorian = {"Em", "F#m", "G", "A", "Bm", "C#m", "D", "Em7", "F#m7", "GMaj7", "A7", "Bm7", "C#m7b5", "DMaj7"}
FDorian = {"Fm", "Gm", "G#", "Bb", "Cm", "Ddim", "Eb", "Fm7", "Gm7", "G#Maj7", "Bb7", "Cm7", "Dm7b5", "EbMaj7"}
FsDorian = {"F#m", "G#m", "A", "B", "C#m", "Ebdim", "E", "F#m7", "G#m7", "AMaj7", "B7", "C#m7", "Ebm7b5", "EMaj7"}
GbDorian = {"Gbm", "G#m", "A", "B", "C#m", "Ebdim", "E", "Gbm7", "G#m7", "AMaj7", "B7", "C#m7", "Ebm7b5", "EMaj7"}
GDorian = {"Gm", "Am", "Bb", "C", "Dm", "Edim", "F", "Gm7", "Am7", "BbMaj7", "C7", "Dm7", "Em7b5", "FMaj7"}
GsDorian = {"G#m", "Bbm", "B", "C#", "Ebm", "Fdim", "F#", "G#m7", "Bbm7", "BMaj7", "C#7", "Ebm7", "Fm7b5", "F#Maj7"}
AbDorian = {"Abm", "Bbm", "B", "C#", "Ebm", "Fdim", "F#", "Abm7", "Bbm7", "BMaj7", "C#7", "Ebm7", "Fm7b5", "F#Maj7"}
ADorian = {"Am", "Bm", "C", "D", "Em", "F#dim", "G", "Am7", "Bm7", "CMaj7", "D7", "Em7", "F#m7b5", "Gmaj7"}
AsDorian = {"A#m", "Cm", "C3", "Eb", "Fm", "Gdim", "G#", "Bbm7", "Cm7", "C#Maj7", "Eb7", "Fm7", "Gm7b5", "G#maj7"}
BbDorian = {"Bbm", "Cm", "C3", "Eb", "Fm", "Gdim", "G#", "Bbm7", "Cm7", "C#Maj7", "Eb7", "Fm7", "Gm7b5", "G#maj7"}
BDorian = {"Bm", "C#mD", "E", "F#m", "G#dim", "A", "Bm7", "C#m7", "DMaj7", "E7", "F#7", "G#m7b5", "AMaj7"}


CPhrygian = {"Cm", "Db", "Eb", "Fm", "Gdim", "Ab", "Bbm", "Cm7", "DbMaj7", "Eb7", "Fm7", "Gm7b5", "AbMaj7", "Bbm"}
CsPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DbPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DsPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EbPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FsPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GbPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GsPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AbPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
APhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AsPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BbPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BPhrygian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}

CLydian = {"C", "D", "Em", "Gbdim", "G", "Am", "Bm", "CMaj7", "D7", "Em7", "Gbm7b5", "GMaj", "7Am7", "Bm7"}
CsLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DbLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DsLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EbLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
ELydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FsLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GbLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GsLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AbLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
ALydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AsLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BbLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BLydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}


CMixolydian = {"C", "Dm", "Edim", "F", "Gm", "Am", "Bb", "C7", "Dm7", "Em7b5", "FMaj7", "Gm7", "Am7", "BbMaj7"}
CsMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DbMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DsMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EbMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FsMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GbMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GsMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AbMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AsMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BbMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BMixolydian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}


CAeolian = {"Cm", "Ddim", "Eb", "Fm", "Gm", "Ab", "Bb", "Cm7", "Dm7b5", "Fm7", "Gm7", "AbMaj7", "Bb7"}
CsAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DbAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DsAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EbAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FsAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GbAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GsAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AbAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AsAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BbAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BAeolian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}


CLocrian = {"Cdim", "C#", "Ebm", "Fm", "F#", "Ab", "Bdim", "Cm7b5", "DbMaj7", "Ebm7", "Fm7", "F#Maj7", "Ab7", "Bbm7"}
CsLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DbLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
DsLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
EbLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
ELocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
FsLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GbLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
GsLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AbLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
ALocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
AsLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BbLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}
BLocrian = { "", "", "", "", "", "", "", "", "", "", "", "", "", ""}






--chord = minor_c
--chord4 = major_chords_c[6] 
--Msg("Major Chord C =")
--Msg(major_chords_c[6])
--local note_names = { [1] = "C", [2] = "Dm", [3] = "Em", [4] = "F", [5] = "G", [6] = "Am", [7] = "Bdim", [8] = "CMaj7", [9] = "Dm7", [10] = "Em7", [11] = "FMaj7", [12] = "G7", [13] = "Am7", [14] = "Bm7b5"}
--local note_names = { [1] = "C", [2] = "Dm", [3] = "Em", [4] = "F", [5] = "G", [6] = "Am", [7] = "Bdim", [8] = "CMaj7", [9] = "Dm7", [10] = "Em7", [11] = "FMaj7", [12] = "G7", [13] = "Am7", [14] = "Bm7b5"}

--local selected_note = note_names[number]

--local selected_note = major_chords[inkey]
--Msg(selected_note)



local function key_chord_input()
    time = reaper.GetCursorPosition()
    markrgnindexnumber, rgnendOut = reaper.GetLastMarkerAndCurRegion(0, time)
    retval, isrgnOut, posOut, rgnendOut, nameOut, markrgnindexnumberOut = reaper.EnumProjectMarkers(rgnendOut)
    clear_name_flag = 0 --this flag is needed in the SetProjectMarker4 function to enable the region name to be cleared
    --root_name = GUI.elms.root_choice.optarray[ GUI.Val("root_choice") ]
    --newName = (root_name .. chord_type) --newName = ("C" .. chord_type)
    
    --Msg(newName)
    --- if newName == "" then clear_name_flag = 1 end --if removing the -L leaves an empty name string pass the 1 flag to clear name
    reaper.SetProjectMarker4(0, markrgnindexnumberOut, true, posOut, rgnendOut, keychordName, 0, clear_name_flag)
    --chord_type = ""
    commandID74 = reaper.NamedCommandLookup("_RSce47da3c9b1238de71cc94a1cb99732b9abd5e41")
    reaper.Main_OnCommand(commandID74, 0) -- Script: ReaTrak Go to start of next region.lua
	   
    end
function btn_click_chord1()
    keychordName = chord[1]
    key_chord_input ()
    
    end    
function btn_click_chord2()
    keychordName = chord[2]
    key_chord_input ()
    end
    
function btn_click_chord3()
    keychordName = chord[3]
    key_chord_input ()
    end

function btn_click_chord4()
    keychordName = chord[4]
    key_chord_input ()
    end
function btn_click_chord5()
    keychordName = chord[5]
    key_chord_input ()
    end
function btn_click_chord6()
    keychordName = chord[6]
    key_chord_input ()
    end
function btn_click_chord7()
    keychordName = chord[7]
    key_chord_input ()
    end
function btn_click_chord8()
    keychordName = chord[8]
    key_chord_input ()
    end
function btn_click_chord9()
    keychordName = chord[9]
    key_chord_input ()
    end
function btn_click_chord10()
    keychordName = chord[10]
    key_chord_input ()
    end
function btn_click_chord11()
    keychordName = chord[11]
    key_chord_input ()
    end
function btn_click_chord12()
    keychordName = chord[12]
    key_chord_input ()
    end
function btn_click_chord13()
    keychordName = chord[13]
    key_chord_input ()
    end
function btn_click_chord14()
    keychordName = chord[14]
    key_chord_input ()
    end







--GUI.New("my_frm9",      "Frame",           4, 32, 255, 340, 20, true, true, "elm_bg", 4)
--function update_buttons()
--end


    GUI.New("key_choice",     "Radio",          4, 200, 100, 610, 110, "Select Key", "C,C♯,Db,D,D♯,Eb,E,F,F♯,Gb,G,G♯,Ab,A,A♯,Bb,B", "h", 15)
	--GUI.elms.my_frm9.text = " Choose Your Key"
	--GUI.elms.my_frm9.col_txt = "white"
	
    GUI.New("scale_choice",     "Radio",          4, 20, 100, 140, 330, "Select Scale", "Major,Minor,Harmonic Major,Harmonic Minor,Melodic Major,Melodic Minor,Ionian,Dorian,Phrygian,Lydian,Mixolydian,Aeolian,Locrian", "v", 4)
	    --if GUI.elms.key_choice.optarray then GUI.elms.lb_key_chord = nil end
	    scale = GUI.elms.scale_choice.optarray[ GUI.Val("scale_choice") ]
	    inkey = GUI.elms.key_choice.optarray[ GUI.Val("key_choice") ]
	--if scale == nil then scale = "Major" end
	--if inkey == nil then inkey = "C" end
 
	
	--chord1 = "C"  
	--GUI.elm_updated = false 
	    --Msg("Scale")
	   -- Msg(scale)
	--if scale  == "Minor" then scale_minor() end
--scale = GUI.elms.scale_choice.optarray[ GUI.Val("scale_choice") ]
--inkey = GUI.elms.key_choice.optarray[ GUI.Val("key_choice") ]    
--local tblAlphabet = {"a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z"};
--Msg(tblAlphabet[4])

-- Radio call funtion on click

function GUI.elms.key_choice:onmouseup()
    -- Run the original method
    GUI.Radio.onmouseup(self)

    -- And then your function
    update_chord_buttons()
end

function GUI.elms.scale_choice:onmouseup()
    -- Run the original method
    GUI.Radio.onmouseup(self)

    -- And then your function
    update_chord_buttons() 
end 

--Update Chord Buttons to new Key/Scale      

function update_chord_buttons () 
	  
--Delete old buttons before updating  

    GUI.elms.lb_chords_on:ondelete() 
    GUI.elms.lb_key_chord:ondelete()     
    GUI.elms.key_chord1:ondelete() 
    GUI.elms.key_chord2:ondelete()    
    GUI.elms.key_chord3:ondelete()     
    GUI.elms.key_chord4:ondelete()     
    GUI.elms.key_chord5:ondelete()     
    GUI.elms.key_chord6:ondelete()     
    GUI.elms.key_chord7:ondelete()    
    GUI.elms.key_chord8:ondelete()     
    GUI.elms.key_chord9:ondelete()     
    GUI.elms.key_chord10:ondelete()     
    GUI.elms.key_chord11:ondelete()     
    GUI.elms.key_chord12:ondelete()     
    GUI.elms.key_chord13:ondelete()     
    GUI.elms.key_chord14:ondelete()     
  
    
--Use Legal characters from Radio s=# and remove underscore    
			    
    key_numbers = GUI.Val("key_choice")
    key_names = { [1] = "C", [2] = "Cs", [3] = "Db", [4] = "D", [5] = "Ds", [6] = "Eb", [7] = "E", [8] = "F", [9] = "Fs", [10] = "Gb", [11] = "G", [12] = "Gs", [13] = "Ab", [14] = "A", [15] = "As", [16] = "Bb", [17] = "B"}
    selected_key = key_names[key_numbers]
    
    scale_numbers = GUI.Val("scale_choice")
    scale_names = { [1] = "Major", [2] = "Minor", [3] = "Harmonic_Major", [4] = "Harmonic_Minor", [5] = "Melodic_Major", [6] = "Melodic_Minor", [7] = "Ionian", [8] = "Dorian", [9] = "Phrygian", [10] = "Lydian", [11] = "Mixolydian", [12] = "Aeolian", [13] = "Locrian"}
    selected_scale = scale_names[scale_numbers] 

		 
	   
    scale = GUI.elms.scale_choice.optarray[ GUI.Val("scale_choice") ]
    inkey = GUI.elms.key_choice.optarray[ GUI.Val("key_choice") ]    
    --chord, value =  inkey .. scale  
    --
    --chord_val = tostring(inkey .. scale)
    chord_val = tostring(selected_key .. selected_scale)
    chord = _G[chord_val]
    --newchord = string.gsub(chord_val, s, "#")
    --newname = chord_val:gsub(s, "#")
    newname = chord_val
    newname = newname:gsub("s", "♯")
    newname2 = newname:gsub("_", " ")
    
    --Msg("Key Scale")
   -- Msg(chord_val)
    --Msg(CMinor[3])
    --Msg (inkey)

    GUI.New("lb_chords_on",      "Label",           4, 20+x9, 0+y9, "Chords on", true, 1)
    GUI.New("lb_key_chord",      "Label",           4, 155+x9, 0+y9, newname2, true, 1)
    GUI.New("key_chord1",      "Button",           4, 16+x9, 55+y9, 70, 20, chord[1], btn_click_chord1)
    GUI.New("key_chord2",      "Button",           4, 96+x9, 55+y9, 70, 20, chord[2], btn_click_chord2)
    GUI.New("key_chord3",      "Button",           4, 176+x9, 55+y9, 70, 20, chord[3], btn_click_chord3)
    GUI.New("key_chord4",      "Button",           4, 256+x9, 55+y9, 70, 20, chord[4], btn_click_chord4)
    GUI.New("key_chord5",      "Button",           4, 336+x9, 55+y9, 70, 20, chord[5], btn_click_chord5)
    GUI.New("key_chord6",      "Button",           4, 416+x9, 55+y9, 70, 20, chord[6], btn_click_chord6)
    GUI.New("key_chord7",      "Button",           4, 496+x9, 55+y9, 70, 20, chord[7], btn_click_chord7)
	
    GUI.New("key_chord8",      "Button",           4, 16+x9, 80+y9, 70, 20, chord[8], btn_click_chord8)
    GUI.New("key_chord9",      "Button",           4, 96+x9, 80+y9, 70, 20, chord[9], btn_click_chord9)
    GUI.New("key_chord10",      "Button",           4, 176+x9, 80+y9, 70, 20, chord[10], btn_click_chord10)
    GUI.New("key_chord11",      "Button",           4, 256+x9, 80+y9, 70, 20, chord[11], btn_click_chord11)
    GUI.New("key_chord12",      "Button",           4, 336+x9, 80+y9, 70, 20, chord[12], btn_click_chord12)
    GUI.New("key_chord13",      "Button",           4, 416+x9, 80+y9, 70, 20, chord[13], btn_click_chord13)
    GUI.New("key_chord14",      "Button",           4, 496+x9, 80+y9, 70, 20, chord[14], btn_click_chord14)
   

    
end

--chordname1 = GUI.Val("key_choice")
--button_1.func = new_chord_function

    key_numbers = GUI.Val("key_choice")
    key_names = { [1] = "C", [2] = "Cs", [3] = "Db", [4] = "D", [5] = "Ds", [6] = "Eb", [7] = "E", [8] = "F", [9] = "Fs", [10] = "Gb", [11] = "G", [12] = "Gs", [13] = "Ab", [14] = "A", [15] = "As", [16] = "Bb", [17] = "B"}
    selected_key = key_names[key_numbers]
    
    scale_numbers = GUI.Val("scale_choice")
    scale_names = { [1] = "Major", [2] = "Minor", [3] = "Harmonic_Major", [4] = "Harmonic_Minor", [5] = "Melodic_Major", [6] = "Melodic_Minor", [7] = "Ionian", [8] = "Dorian", [9] = "Phrygian", [10] = "Lydian", [11] = "Mixolydian", [12] = "Aeolian", [13] = "Locrian"}
    selected_scale = scale_names[scale_numbers] 
	   
	   
    scale = GUI.elms.scale_choice.optarray[ GUI.Val("scale_choice") ]
    inkey = GUI.elms.key_choice.optarray[ GUI.Val("key_choice") ]    
    --chord, value =  inkey .. scale  
    --
    --chord_val = tostring(inkey .. scale)
    chord_val = tostring(selected_key .. scale)
    chord = _G[chord_val]
    --newchord = string.gsub(chord_val, s, "#")
    --newname = chord_val:gsub(s, "#")
    newname = chord_val
    newname2 = newname:gsub("s", "♯") 

-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10    
    x9 = 200
    y9 = 220

    GUI.New("lb_chords_on",      "Label",           4, 20+x9, 0+y9, "Chords on", true, 1)
    GUI.New("lb_key_chord",      "Label",           4, 155+x9, 0+y9, newname2, true, 1)
    GUI.New("key_chord1",      "Button",           4, 16+x9, 55+y9, 70, 20, chord[1], btn_click_chord1)
    GUI.New("key_chord2",      "Button",           4, 96+x9, 55+y9, 70, 20, chord[2], btn_click_chord2)
    GUI.New("key_chord3",      "Button",           4, 176+x9, 55+y9, 70, 20, chord[3], btn_click_chord3)
    GUI.New("key_chord4",      "Button",           4, 256+x9, 55+y9, 70, 20, chord[4], btn_click_chord4)
    GUI.New("key_chord5",      "Button",           4, 336+x9, 55+y9, 70, 20, chord[5], btn_click_chord5)
    GUI.New("key_chord6",      "Button",           4, 416+x9, 55+y9, 70, 20, chord[6], btn_click_chord6)
    GUI.New("key_chord7",      "Button",           4, 496+x9, 55+y9, 70, 20, chord[7], btn_click_chord7)
	
    GUI.New("key_chord8",      "Button",           4, 16+x9, 80+y9, 70, 20, chord[8], btn_click_chord8)
    GUI.New("key_chord9",      "Button",           4, 96+x9, 80+y9, 70, 20, chord[9], btn_click_chord9)
    GUI.New("key_chord10",      "Button",           4, 176+x9, 80+y9, 70, 20, chord[10], btn_click_chord10)
    GUI.New("key_chord11",      "Button",           4, 256+x9, 80+y9, 70, 20, chord[11], btn_click_chord11)
    GUI.New("key_chord12",      "Button",           4, 336+x9, 80+y9, 70, 20, chord[12], btn_click_chord12)
    GUI.New("key_chord13",      "Button",           4, 416+x9, 80+y9, 70, 20, chord[13], btn_click_chord13)
    GUI.New("key_chord14",      "Button",           4, 496+x9, 80+y9, 70, 20, chord[14], btn_click_chord14)








---------------------------------------------------------------------
--Chords Tab 3 (layers 2,5)
---------------------------------------------------------------------

--Chord Input

local function chord_input()
    time = reaper.GetCursorPosition()
    markrgnindexnumber, rgnendOut = reaper.GetLastMarkerAndCurRegion(0, time)
    retval, isrgnOut, posOut, rgnendOut, nameOut, markrgnindexnumberOut = reaper.EnumProjectMarkers(rgnendOut)
    clear_name_flag = 0 --this flag is needed in the SetProjectMarker4 function to enable the region name to be cleared
    root_numbers = GUI.Val("root_choice")
    root_names = { [1] = "C", [2] = "C#", [3] = "Db", [4] = "D", [5] = "D#", [6] = "Eb", [7] = "E", [8] = "F", [9] = "F#", [10] = "Gb", [11] = "G", [12] = "G#", [13] = "Ab", [14] = "A", [15] = "A#", [16] = "Bb", [17] = "B"}
    root_name = root_names[root_numbers]    
	    
    --root_name = GUI.elms.root_choice.optarray[ GUI.Val("root_choice") ]
    newName = (root_name .. chord_type) --newName = ("C" .. chord_type)
--Msg(newName)
    --- if newName == "" then clear_name_flag = 1 end --if removing the -L leaves an empty name string pass the 1 flag to clear name
    reaper.SetProjectMarker4(0, markrgnindexnumberOut, true, posOut, rgnendOut, newName, 0, clear_name_flag)
    chord_type = ""
    commandID74 = reaper.NamedCommandLookup("_RSce47da3c9b1238de71cc94a1cb99732b9abd5e41")
    reaper.Main_OnCommand(commandID74, 0) -- Script: ReaTrak Go to start of next region.lua
	   
    end
    
  
    


-- Major Chords Functions        
    
function btn_click_Maj()
    chord_type = ""
    chord_input ()
    end  

function btn_click_6()
    chord_type = "6"
    chord_input ()
    end         
    
function btn_click_6sus4()
    chord_type = "6sus4"
    chord_input ()
    end         

function btn_click_69()
    chord_type = "69"
    chord_input ()
    end         

function btn_click_Maj7()
    chord_type = "Maj7"
    chord_input ()
    end         

function btn_click_Maj7b5()
    chord_type = "Maj7b5"
    chord_input ()
    end         

function btn_click_Maj7s5()
    chord_type = "Maj7#5"
    chord_input ()
    end         

function btn_click_Maj7s11()
    chord_type = "Maj7#11"
    chord_input ()
    end 

function btn_click_Maj7add13()
    chord_type = "Maj7add13"
    chord_input ()
    end         

function btn_click_Maj9()
    chord_type = "Maj9"
    chord_input ()
    end         

function btn_click_Maj9sus4()
    chord_type = "Maj9sus4"
    chord_input ()
    end         

function btn_click_Maj9s5()
    chord_type = "Maj9#5"
    chord_input ()
    end         

function btn_click_Maj9s11()
    chord_type = "Maj9#11"
    chord_input ()
    end         

function btn_click_Maj11()
    chord_type = "Maj11"
    chord_input ()
    end         

function btn_click_Maj13()
    chord_type = "Maj13"
    chord_input ()
    end 

function btn_click_Maj13s11()
    chord_type = "Maj13#11"
    chord_input ()
    end 

		  

    
-- Major Chords Buttons 
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x5 = 0
y5 = 0   
    

GUI.New("lb_Major",      "Label",           5, 20+x5, 20+y5, "Major", true, 1)
GUI.New("chord_Maj",      "Button",           5, 16+x5, 55+y5, 85, 20, "Maj", btn_click_Maj)
GUI.New("chord_Maj6",      "Button",           5, 16+x5, 80+y5, 85, 20, "6", btn_click_6)
GUI.New("chord_Maj6sus4",      "Button",           5, 16+x5, 105+y5, 85, 20, "6sus4", btn_click_6sus4)
GUI.New("chord_Maj69",      "Button",           5, 16+x5, 130+y5, 85, 20, "69", btn_click_69)
GUI.New("chord_Maj7",      "Button",           5, 16+x5, 155+y5, 85, 20, "Maj7", btn_click_Maj7)
GUI.New("chord_Maj7b5",      "Button",           5, 16+x5, 180+y5, 85, 20, "Maj7b5", btn_click_Maj7b5)
GUI.New("chord_Maj7#5",      "Button",           5, 16+x5, 205+y5, 85, 20, "Maj7#5", btn_click_Maj7s5)
GUI.New("chord_Maj7#11",      "Button",           5, 16+x5, 230+y5, 85, 20, "Maj7#11", btn_click_Maj7s11)
GUI.New("chord_Maj7add13",      "Button",           5, 16+x5, 255+y5, 85, 20, "Maj7add13", btn_click_Maj7add13)
GUI.New("chord_Maj9",      "Button",           5, 16+x5, 280+y5, 85, 20, "Maj9", btn_click_Maj9)
GUI.New("chord_Maj9sus4",      "Button",           5, 16+x5, 305+y5, 85, 20, "Maj9sus4", btn_click_Maj9sus4)
GUI.New("chord_Maj9#5",      "Button",           5, 16+x5, 330+y5, 85, 20, "Maj9#5", btn_click_Maj9s5)
GUI.New("chord_Maj9#11",      "Button",           5, 16+x5, 355+y5, 85, 20, "Maj9#11", btn_click_Maj9s11)
GUI.New("chord_Maj11",      "Button",           5, 16+x5, 380+y5, 85, 20, "Maj11", btn_click_Maj11)
GUI.New("chord_Maj13",      "Button",           5, 16+x5, 405+y5, 85, 20, "Maj13", btn_click_Maj13)
GUI.New("chord_Maj13#11",      "Button",           5, 16+x5, 430+y5, 85, 20, "Maj13#11", btn_click_Maj13s11)

-- Major Chords Buttons Column 2
--GUI.New("chord_Maj2",      "Button",           5, 105+x5, 55+y5, 85, 20, "Maj", btn_click_Maj)


--GUI.New("btn_frm5",     "Frame",          5, 0, 465, 300, 4, true, true)
--GUI.New("btn_frm6",     "Frame",          5, 298, 465, 4, 160, true, true)
--GUI.New("btn_frm7",     "Frame",          5, 0, 620, 300, 4, true, true)



function btn_click_dim()
    chord_type = "dim"
    chord_input ()
    end

function btn_click_dim7()
    chord_type = "dim7"
    chord_input ()
    end
function btn_click_m7b5()
    chord_type = "m7b5"
    chord_input ()
    end

function btn_click_m9b5()
    chord_type = "m9b5"
    chord_input ()
    end




--Diminished Chords Buttons

GUI.New("lb_Dim",      "Label",           5, 40+x5, 470+y5, "Dim", true, 1)
GUI.New("chord_dim",      "Button",           5, 16+x5, 505+y5, 85, 20, "dim", btn_click_dim)
GUI.New("chord_dim7",      "Button",           5, 16+x5,530+y5, 85, 20, "dim7", btn_click_dim7)
GUI.New("chord_m7b5",      "Button",           5, 16+x5,555+y5, 85, 20, "m7b5", btn_click_m7b5)
GUI.New("chord_m9b5",      "Button",           5, 16+x5, 580+y5, 85, 20, "m9b5", btn_click_m9b5)



--Minor Chords Functions

function btn_click_m()
    chord_type = "m"
    chord_input ()
    end         

function btn_click_ms5()
    chord_type = "m#5"
    chord_input ()
    end 
    
function btn_click_m6()
    chord_type = "m6"
    chord_input ()
    end         

function btn_click_m6add9()
    chord_type = "m6add9"
    chord_input ()
    end         

function btn_click_m7()
    chord_type = "m7"
    chord_input ()
    end         

function btn_click_m7b9()
    chord_type = "m7m7b9"
    chord_input ()
    end         

function btn_click_m7add11()
    chord_type = "m7add11"
    chord_input ()
    end         

function btn_click_m7add13()
    chord_type = "m7add13"
    chord_input ()
    end         

function btn_click_mMaj7add13()
    chord_type = "mMaj7add13"
    chord_input ()
    end

function btn_click_mMaj7()
    chord_type = "mMaj7"
    chord_input ()
    end         

function btn_click_mMaj7add11()
    chord_type = "mMaj7add11"
    chord_input ()
    end         

function btn_click_mMaj7add13()
    chord_type = "mMaj7add13"
    chord_input ()
    end         

function btn_click_m9()
    chord_type = "m9"
    chord_input ()
    end         

function btn_click_mMaj9()
    chord_type = "mMaj9"
    chord_input ()
    end         

function btn_click_m11()
    chord_type = "m11"
    chord_input ()
    end         

function btn_click_mMaj11()
    chord_type = "mMaj11"
    chord_input ()
    end         

function btn_click_m13()
    chord_type = "m13"
    chord_input ()
    end         

function btn_click_mMaj13()
    chord_type = "mMaj13"
    chord_input ()
    end         



--Minor Chords Buttons

GUI.New("lb_Minor",      "Label",           5, 195+x5, 20+y5, "Minor", true, 1)
GUI.New("chord_m",      "Button",           5, 193+x5, 55+y5, 85, 20, "m", btn_click_m)
GUI.New("chord_m#5",      "Button",           5, 193+x5, 80+y5, 85, 20, "m#5", btn_click_ms5)
GUI.New("chord_m6",      "Button",           5, 195+x5, 105+y5, 85, 20, "m6", btn_click_m6)
GUI.New("chord_madd9",      "Button",           5, 195+x5, 130+y5, 85, 20, "m6add9", btn_click_m6add9)
GUI.New("chord_m7",      "Button",           5, 195+x5, 155+y5, 85, 20, "m7", btn_click_m7)
GUI.New("chord_m7b9",      "Button",           5, 195+x5, 180+y5, 85, 20, "m7b9", btn_click_m7b9)
GUI.New("chord_m7add11",      "Button",           5, 195+x5, 205+y5, 85, 20, "m7add11", btn_click_m7add11)
GUI.New("chord_m7add13",      "Button",           5, 195+x5, 230+y5, 85, 20, "m7add13", btn_click_m7add13)
GUI.New("chord_m7b5(2)",      "Button",           5, 193+x5, 255+y5, 85, 20, "m7b5", btn_click_m7b5)
GUI.New("chord_m7#5(2)",      "Button",           5, 193+x5, 280+y5, 85, 20, "m7#5", btn_click_m7s5)
GUI.New("chord_mMaj7",      "Button",           5, 195+x5, 305+y5, 85, 20, "mMaj7", btn_click_mMaj7)
GUI.New("chord_mMaj7add11",      "Button",           5, 195+x5, 330+y5, 85, 20, "mMaj7add1", btn_click_mMaj7add11)
GUI.New("chord_mMaj7add13",      "Button",           5, 195+x5, 355+y5, 85, 20, "mMaj7add13", btn_click_mMaj7add13)
GUI.New("chord_m9",      "Button",           5, 195+x5, 380+y5, 85, 20, "m9", btn_click_m9)
GUI.New("chord_mMaj9",      "Button",           5, 195+x5, 405+y5, 85, 20, "mMaj9", btn_click_mMaj9)
GUI.New("chord_m11",      "Button",           5, 195+x5, 430+y5, 85, 20, "m11", btn_click_m11)

--Minor Chords Buttons Column 2

GUI.New("chord_mMaj11",      "Button",           5, 281+x5, 55+y5, 85, 20, "mMaj11", btn_click_mMaj11)
GUI.New("chord_m13",      "Button",           5, 281+x5, 80+y5, 85, 20, "m13", btn_click_m13)
GUI.New("chord_mMaj13",      "Button",           5, 281+x5, 105+y5, 85, 20, "mMaj13", btn_click_mMaj13)


--Augmented Chords Buttons Fuctions

function btn_click_aug()
    chord_type = "aug"
    chord_input ()
    end

function btn_click_aug7()
    chord_type = "aug7"
    chord_input ()
    end


--Augmented Chords Buttons

GUI.New("lb_Aug",      "Label",           5, 200+x5, 470+y5, "Aug", true, 1)
GUI.New("chord_Aug",      "Button",           5, 195+x5, 505+y5, 85, 20, "aug", btn_click_aug)
GUI.New("chord_Aug7",      "Button",           5, 195+x5, 530+y5, 85, 20, "aug7", btn_click_aug7)




--Dominant Chords Buttons Functions

function btn_click_7()
    chord_type = "7"
    chord_input ()
    end  

function btn_click_7b5()
    chord_type = "7b5"
    chord_input ()
    end         
    
function btn_click_7s5()
    chord_type = "7#5"
    chord_input ()
    end         

function btn_click_7b9()
    chord_type = "7b9"
    chord_input ()
    end         

function btn_click_7s9()
    chord_type = "7#9"
    chord_input ()
    end         

function btn_click_7b5b9()
    chord_type = "7b5b9"
    chord_input ()
    end         

function btn_click_7b5b13()
    chord_type = "7b5b13"
    chord_input ()
    end 
    
function btn_click_7b5b9b13()
    chord_type = "7b5b9b13"
    chord_input ()
    end   
	
function btn_click_7b5s9()
    chord_type = "7b5#9"
    chord_input ()
    end 

function btn_click_7b9b13()
    chord_type = "7b9b13"
    chord_input ()
    end

function btn_click_7b9s13()
    chord_type = "7b9#s13"
    chord_input ()
    end
    
function btn_click_7b5s9()
    chord_type = "7b5#9"
    chord_input ()
    end

function btn_click_7b9s11()
    chord_type = "7b9#11"
    chord_input ()
    end

function btn_click_7b9s11b13()
    chord_type = "7b9#11b13"
    chord_input ()
    end
    
function btn_click_7b13()
    chord_type = "7b13"
    chord_input ()
    end

function btn_click_7s5b9()
    chord_type = "7#5b9"
    chord_input ()
    end
						  
function btn_click_7add11()
    chord_type = "7add11"
    chord_input ()
    end         

function btn_click_7s5s9()
    chord_type = "7#5#9"
    chord_input ()
    end

function btn_click_7s5s11()
    chord_type = "7#5#11"
    chord_input ()
    end

function btn_click_7s5s11b13()
    chord_type = "7#5#11b13"
    chord_input ()
    end  

function btn_click_7b9s13()
    chord_type = "7b9#13"
    chord_input ()
    end
function btn_click_7s9b13()
    chord_type = "7#9b13"
    chord_input ()
    end
function btn_click_9b5b13()
    chord_type = "9b5b13"
    chord_input ()
    end 

function btn_click_9s5s11()
    chord_type = "9#5#11"
    chord_input ()
    end

function btn_click_9s11b13()
    chord_type = "9#11b13"
    chord_input ()
    end
					
function btn_click_7s11()
    chord_type = "7#11"
    chord_input ()
    end 

function btn_click_7s11b13()
    chord_type = "7#11b13"
    chord_input ()
    end
    
function btn_click_7add13()
    chord_type = "7add13"
    chord_input ()
    end         


--Dominant Chords Buttons Functions Column 2

function btn_click_9()
    chord_type = "9"
    chord_input ()
    end         

function btn_click_9b5()
    chord_type = "9b5"
    chord_input ()
    end         

function btn_click_9s5()
    chord_type = "9#5"
    chord_input ()
    end         

function btn_click_9s11()
    chord_type = "9#11"
    chord_input ()
    end         

function btn_click_9b13()
    chord_type = "9b13"
    chord_input ()
    end         

function btn_click_11()
    chord_type = "11"
    chord_input ()
    end         

function btn_click_11b9()
    chord_type = "11b9"
    chord_input ()
    end         

function btn_click_13()
    chord_type = "13"
    chord_input ()
    end         

function btn_click_13b5()
    chord_type = "13b5"
    chord_input ()
    end         

function btn_click_13b5b9()
    chord_type = "13b5b9"
    chord_input ()
    end
    
function btn_click_13b9()
    chord_type = "13b9"
    chord_input ()
    end  
		 
function btn_click_13b9s11()
    chord_type = "13b9#11"
    chord_input ()
    end
    
function btn_click_13s5()
    chord_type = "13#5"
    chord_input ()
    end    

function btn_click_13s5b9()
    chord_type = "13#5b9"
    chord_input ()
    end

function btn_click_13s5s11()
    chord_type = "13#5#11"
    chord_input ()
    end
    
function btn_click_13s5b9s11()
    chord_type = "13#5b9#11"
    chord_input ()
    end

function btn_click_13s5s9s11()
    chord_type = "13#5#9#11"
    chord_input ()
    end
				
function btn_click_13s9()
    chord_type = "13#9"
    chord_input ()
    end         

function btn_click_13s9s11()
    chord_type = "13#9#11"
    chord_input ()
    end
		  
function btn_click_13s11()
    chord_type = "13#11"
    chord_input ()
    end





--Dominant Chords Buttons

GUI.New("lb_Dom",      "Label",           5, 370+x5, 20+y5, "Dom", true, 1)
GUI.New("chord_7",      "Button",           5, 369+x5, 55+y5, 85, 20, "7", btn_click_7)
GUI.New("chord_7b5",      "Button",           5, 369+x5, 80+y5, 85, 20, "7b5", btn_click_7b5)
GUI.New("chord_7b5b9",      "Button",           5, 369+x5, 105+y5, 85, 20, "7b5b9", btn_click_7b5b9)
GUI.New("chord_7b5b13",      "Button",           5, 369+x5, 130+y5, 85, 20, "7b5b13", btn_click_7b5b13)
GUI.New("chord_7b5b9b13",      "Button",           5, 369+x5, 155+y5, 85, 20, "7b5b9b13", btn_click_7b5b9b13)
GUI.New("chord_7b5#9",      "Button",           5, 369+x5, 180+y5, 85, 20, "7b5#9", btn_click_7b5s9)
GUI.New("chord_7b9",      "Button",           5, 369+x5, 205+y5, 85, 20, "7b9", btn_click_7b9)
GUI.New("chord_7b9b13",      "Button",           5, 369+x5, 230+y5, 85, 20, "7b9b13", btn_click_7b9b13)
GUI.New("chord_7b9#11",      "Button",           5, 369+x5, 255+y5, 85, 20, "7b9#11", btn_click_7b9s11)
GUI.New("chord_7b9#11b13",      "Button",           5, 369+x5, 280+y5, 85, 20, "7b9#11b13", btn_click_7b9s11b13)
GUI.New("chord_7b13",      "Button",           5, 369+x5, 305+y5, 85, 20, "7b13", btn_click_7b13)
GUI.New("chord_7#5b9",      "Button",           5, 369+x5, 330+y5, 85, 20, "7#5b9", btn_click_7s5b9)
GUI.New("chord_7#5",      "Button",           5, 369+x5, 355+y5, 85, 20, "7#5", btn_click_7s5)
GUI.New("chord_7#5#9",      "Button",           5, 369+x5, 380+y5, 85, 20, "7#5#9", btn_click_7s5s9)
GUI.New("chord_7#5#11",      "Button",           5, 369+x5, 405+y5, 85, 20, "7#5#11", btn_click_7s5s11)
GUI.New("chord_7#9",      "Button",           5, 369+x5, 430+y5, 85, 20, "7#9", btn_click_7s9)
GUI.New("chord_7#9#11b13",      "Button",           5, 369+x5, 455+y5, 85, 20, "7#9#11b13", btn_click_7s9s11b13)
GUI.New("chord_7#9b13",      "Button",           5, 369+x5, 480+y5, 85, 20, "7#9b13", btn_click_7s9b13)
GUI.New("chord_7#11",      "Button",           5, 369+x5, 505+y5, 85, 20, "7#11", btn_click_7s11)
GUI.New("chord_7#11b13",      "Button",           5, 369+x5, 530+y5, 85, 20, "7#11b13", btn_click_7s11b13)
GUI.New("chord_7add11",      "Button",           5, 369+x5, 555+y5, 85, 20, "7add11", btn_click_7add11)
GUI.New("chord_7add13",      "Button",           5, 369+x5, 580+y5, 85, 20, "7add13", btn_click_7add13)

--Dominant Chords Buttons Column 2

GUI.New("chord_9",      "Button",           5, 457+x5, 55+y5, 85, 20, "9", btn_click_9)
GUI.New("chord_9b5",      "Button",           5, 457+x5, 80+y5, 85, 20, "9b5", btn_click_9b5)
GUI.New("chord_9b5b13",      "Button",           5, 457+x5, 105+y5, 85, 20, "9b5b13", btn_click_9b5b13)
GUI.New("chord_9b13",      "Button",           5, 457+x5, 130+y5, 85, 20, "9b13", btn_click_9b13)
GUI.New("chord_9#5",      "Button",           5, 457+x5, 155+y5, 85, 20, "9#5", btn_click_9s5)
GUI.New("chord_9#5#11",      "Button",           5, 457+x5, 180+y5, 85, 20, "9#5#11", btn_click_9s5s11)
GUI.New("chord_9#11",      "Button",           5, 457+x5, 205+y5, 85, 20, "9#11", btn_click_9s11)
GUI.New("chord_9#11b13",      "Button",           5, 457+x5, 230+y5, 85, 20, "9#11b13", btn_click_9s11b13)
GUI.New("chord_11",      "Button",           5, 457+x5, 255+y5, 85, 20, "11", btn_click_11)
GUI.New("chord_11b9",      "Button",           5, 457+x5, 280+y5, 85, 20, "11b9", btn_click_11b9)
GUI.New("chord_13",      "Button",           5, 457+x5, 305+y5, 85, 20, "13", btn_click_13)
GUI.New("chord_13b5",      "Button",           5, 457+x5, 330+y5, 85, 20, "13b5", btn_click_13b5)
GUI.New("chord_13b5b9",      "Button",           5, 457+x5, 355+y5, 85, 20, "13b5b9", btn_click_13b5b9)
GUI.New("chord_13b9",      "Button",           5, 457+x5, 380+y5, 85, 20, "13b9", btn_click_13b9)
GUI.New("chord_13b9#11",      "Button",           5, 457+x5, 405+y5, 85, 20, "13b9#11", btn_click_13b9s11)
GUI.New("chord_13#5",      "Button",           5, 457+x5, 430+y5, 85, 20, "13#5", btn_click_13s5)
GUI.New("chord_13#5b9",      "Button",           5, 457+x5, 455+y5, 85, 20, "13#5b9", btn_click_13s5b9)
GUI.New("chord_13#5b9#11",      "Button",           5, 457+x5, 480+y5, 85, 20, "13#5b9#11", btn_click_13s5b9s11)
GUI.New("chord_13#5#9#11",      "Button",           5, 457+x5, 505+y5, 85, 20, "13#5#9#11", btn_click_13s5s9s11)
GUI.New("chord_13#5#11",      "Button",           5, 457+x5, 530+y5, 85, 20, "13#5#11", btn_click_13s5s11)
GUI.New("chord_13#9",      "Button",           5, 457+x5, 555+y5, 85, 20, "13#9", btn_click_13s9)
GUI.New("chord_13#9#11",      "Button",           5, 457+x5, 580+y5, 85, 20, "13#9#11", btn_click_13s9s11)
GUI.New("chord_13#11",      "Button",           5, 457+x5, 605+y5, 85, 20, "13#11", btn_click_13s11)


--Suspended Chords Buttons Fuctions

function btn_click_sus2()
    chord_type = "sus2"
    chord_input ()
    end


function btn_click_7sus2()
    chord_type = "7sus2"
    chord_input ()
    end
    
function btn_click_9sus2()
    chord_type = "9sus2"
    chord_input ()
    end

function btn_click_sus4()
    chord_type = "7sus"
    chord_input ()
    end
    
function btn_click_7sus4()
    chord_type = "7sus4"
    chord_input ()
    end    

function btn_click_9sus4()
    chord_type = "9sus4"
    chord_input ()
    end
    
function btn_click_7susb5()
    chord_type = "7susb5"
    chord_input ()
    end

function btn_click_7susb5b9()
    chord_type = "7susb5b9"
    chord_input ()
    end
function btn_click_7susb5b9b13()
    chord_type = "7susb5b9b13"
    chord_input ()
    end
function btn_click_7susb5b13()
    chord_type = "7susb5b13"
    chord_input ()
    end
function btn_click_7susb5s9()
    chord_type = "7susb5#9"
    chord_input ()
    end
function btn_click_7susb5s9b13()
    chord_type = "7susb5#9b13"
    chord_input ()
    end
function btn_click_7susb9()
    chord_type = "7susb9"
    chord_input ()
    end
function btn_click_7susb9b13()
    chord_type = "7susb9b13"
    chord_input ()
    end
function btn_click_7susb9s11()
    chord_type = "7susb9s11"
    chord_input ()
    end
function btn_click_7susb9s11b13()
    chord_type = "7susb9#11b13"
    chord_input ()
    end
function btn_click_7susb13()
    chord_type = "7susb13"
    chord_input ()
    end
function btn_click_7suss5()
    chord_type = "7sus#5"
    chord_input ()
    end
function btn_click_7suss5b9()
    chord_type = "7sus#5b9"
    chord_input ()
    end
function btn_click_7suss5s9()
    chord_type = "7sus#5#9"
    chord_input ()
    end
function btn_click_7suss5s9s11()
    chord_type = "7sus#5#9#11"
    chord_input ()
    end
function btn_click_7suss5s11()
    chord_type = "7sus#5#11"
    chord_input ()
    end
function btn_click_7suss9()
    chord_type = "7sus#9"
    chord_input ()
    end
function btn_click_7suss9b13()
    chord_type = "7sus#9b13"
    chord_input ()
    end
function btn_click_7suss9s11b13()
    chord_type = "7sus#9#11b13"
    chord_input ()
    end
function btn_click_7suss11()
    chord_type = "7sus#11"
    chord_input ()
    end
function btn_click_7suss11b13()
    chord_type = "7sus#11b13"
    chord_input ()
    end

function btn_click_9sus()
    chord_type = "9sus"
    chord_input ()
    end

function btn_click_9susb5()
    chord_type = "9susb5"
    chord_input ()
    end
    
function btn_click_9susb5b13()
    chord_type = "9susb5b13"
    chord_input ()
    end
    
function btn_click_9suss11()
    chord_type = "9sus#11"
    chord_input ()
    end
    
function btn_click_9suss5()
    chord_type = "9sus#5"
    chord_input ()
    end
    
function btn_click_9suss5s11()
    chord_type = "9sus#5#11"
    chord_input ()
    end
    
function btn_click_13sus()
    chord_type = "13sus"
    chord_input ()
    end
    
function btn_click_13susb5()
    chord_type = "13susb5"
    chord_input ()
    end
    
function btn_click_13susb5s9()
    chord_type = "13susb5#9"
    chord_input ()
    end

function btn_click_13susb5b9()
    chord_type = "13susb5b9"
    chord_input ()
    end
    
function btn_click_13susb9()
    chord_type = "13susb9"
    chord_input ()
    end
    
function btn_click_13susb9s11()
    chord_type = "13susb9#11"
    chord_input ()
    end
    
function btn_click_13suss5()
    chord_type = "13sus#5"
    chord_input ()
    end
    
function btn_click_13suss5b9()
    chord_type = "13sus#5b9"
    chord_input ()
    end
    
function btn_click_13suss5b9s11()
    chord_type = "13sus#5b9#11"
    chord_input ()
    end
    
function btn_click_13suss5s11()
    chord_type = "13sus#5#11"
    chord_input ()
    end
    
function btn_click_13suss5s9s11()
    chord_type = "13sus#5#9#11"
    chord_input ()
    end
    
function btn_click_13suss9()
    chord_type = "13sus#9"
    chord_input ()
    end
    
function btn_click_13suss9s11()
    chord_type = "13sus#9#11"
    chord_input ()
    end
    
function btn_click_13suss11()
    chord_type = "13sus#11"
    chord_input ()
    end




--Suspended Chords Buttons

GUI.New("lb_Sus",      "Label",           5, 635+x5, 20+y5, "Suspended", true, 1)
GUI.New("lb_Sus2",      "Label",           5, 635+x5, 55+y5, "Sus2", true, 2)
GUI.New("chord_sus2",      "Button",           5, 635+x5, 80+y5, 85, 20, "sus2", btn_click_sus2)
GUI.New("chord_7sus2",      "Button",           5, 635+x5, 105+y5, 85, 20, "7sus2", btn_click_7sus2)
GUI.New("chord_9sus3",      "Button",           5, 635+x5, 130+y5, 85, 20, "9sus2", btn_click_9sus2)
GUI.New("chord_9sus4",      "Button",           5, 635+x5, 230+y5, 85, 20, "9sus4", btn_click_9sus4)
GUI.New("lb_Sus4",      "Label",           5, 640+x5, 155+y5, "Sus4", true, 2)

GUI.New("chord_sus4",      "Button",           5, 635+x5, 180+y5, 85, 20, "sus4", btn_click_sus4)
GUI.New("chord_7sus4",      "Button",           5, 635+x5, 205+y5, 85, 20, "7sus4", btn_click_7sus4)
GUI.New("chord_7susb5",      "Button",           5, 635+x5, 255+y5, 85, 20, "7susb5", btn_click_7susb5)
GUI.New("chord_7susb5b9",      "Button",           5, 635+x5, 280+y5, 85, 20, "7susb5b9", btn_click_7susb5b9)
GUI.New("chord_7susb5b9b13",      "Button",           5, 635+x5, 305+y5, 85, 20, "7susb5b9b13", btn_click_7susb5b9b13)
GUI.New("chord_7susb5b13",      "Button",           5, 635+x5, 330+y5, 85, 20, "7susb5b13", btn_click_7susb5b13)
GUI.New("chord_7susb5#9",      "Button",           5, 635+x5, 355+y5, 85, 20, "7susb5#9", btn_click_7susb5s9)
GUI.New("chord_7susb5#9b13",      "Button",           5, 635+x5, 380+y5, 85, 20, "7susb5#9b13", btn_click_7susb5s9b13)
GUI.New("chord_7susb9",      "Button",           5, 635+x5, 405+y5, 85, 20, "7susb9", btn_click_7susb9)
GUI.New("chord_7susb9b13",      "Button",           5, 635+x5, 430+y5, 85, 20, "7susb9b13", btn_click_7susb9b13)
GUI.New("chord_7susb9#11",      "Button",           5, 635+x5, 455+y5, 85, 20, "7susb9#11", btn_click_7susb9s11)
GUI.New("chord_7susb9#11b13",      "Button",           5, 635+x5, 480+y5, 85, 20, "7susb9#11b13", btn_click_7susb9s11b13)
GUI.New("chord_7susb13",      "Button",           5, 635+x5, 505+y5, 85, 20, "7susb13", btn_click_7susb13)
GUI.New("chord_7sus#5",      "Button",           5, 635+x5, 530+y5, 85, 20, "7sus#5", btn_click_7suss5)
GUI.New("chord_7sus#5b9",      "Button",           5, 635+x5, 555+y5, 85, 20, "7sus#5b9", btn_click_7suss5b9)
GUI.New("chord_7sus#5#9",      "Button",           5, 635+x5, 580+y5, 85, 20, "7sus#5#9", btn_click_7suss5s9)
GUI.New("chord_7sus#5#9#11",      "Button",           5, 635+x5, 605+y5, 85, 20, "7sus#5#9#11", btn_click_7suss5s9s11)



--Suspended Chords Buttons Column 2

GUI.New("chord_7sus#5#11",      "Button",           5, 725+x5, 55+y5, 85, 20, "7sus#5#11", btn_click_7suss5s11)
GUI.New("chord_7sus#9",      "Button",           5, 725+x5, 80+y5, 85, 20, "7sus#9", btn_click_7suss9)
GUI.New("chord_7sus#9b13",      "Button",           5, 725+x5, 105+y5, 85, 20, "7sus#9b13", btn_click_7suss9b13)
GUI.New("chord_7sus#9#11b13 ",      "Button",           5, 725+x5, 130+y5, 85, 20, "7sus#9#11b13", btn_click_7suss9s11b13 )
GUI.New("chord_7sus#11",      "Button",           5, 725+x5, 155+y5, 85, 20, "7sus#11", btn_click_7suss11)
GUI.New("chord_7sus#11b13",      "Button",           5, 725+x5, 180+y5, 85, 20, "7sus#11b13", btn_click_7suss11b13)

GUI.New("chord_9sus",      "Button",           5, 725+x5, 205+y5, 85, 20, "9sus", btn_click_9sus)
GUI.New("chord_9susb5",      "Button",           5, 725+x5, 230+y5, 85, 20, "9susb5", btn_click_9susb5)
GUI.New("chord_9susb5b13",      "Button",           5, 725+x5, 255+y5, 85, 20, "9susb5b13", btn_click_9susb5b13)
GUI.New("chord_9sus#11",      "Button",           5, 725+x5, 280+y5, 85, 20, "9sus#11", btn_click_9suss11)
GUI.New("chord_9sus#5",      "Button",           5, 725+x5, 305+y5, 85, 20, "9sus#5", btn_click_9suss5)
GUI.New("chord_9sus#5#11",      "Button",           5, 725+x5, 330+y5, 85, 20, "9sus#5#11", btn_click_9suss5s11)
GUI.New("chord_13sus",      "Button",           5, 725+x5, 355+y5, 85, 20, "13sus", btn_click_13sus)
GUI.New("chord_13susb5",      "Button",           5, 725+x5, 380+y5, 85, 20, "13susb5", btn_click_13susb5)
GUI.New("chord_13susb5#9",      "Button",           5, 725+x5, 405+y5, 85, 20, "13susb5#9", btn_click_13susb5s9)
GUI.New("chord_13susb5b9",      "Button",           5, 725+x5, 430+y5, 85, 20, "13susb5b9", btn_click_13susb5b9)
GUI.New("chord_13susb9",      "Button",           5, 725+x5, 455+y5, 85, 20, "13susb9", btn_click_13susb9)
GUI.New("chord_13susb9#11",      "Button",           5, 725+x5, 480+y5, 85, 20, "13susb9#11", btn_click_13susb9s11)
GUI.New("chord_13sus#5",      "Button",           5, 725+x5, 505+y5, 85, 20, "13sus#5", btn_click_13suss5)
GUI.New("chord_13sus#5b9",      "Button",           5, 725+x5, 530+y5, 85, 20, "13sus#5b9", btn_click_13suss5b9)
GUI.New("chord_13sus#5b9#11",      "Button",           5, 725+x5, 555+y5, 85, 20, "13sus#5b9#11", btn_click_13suss5b9s11)
GUI.New("chord_13sus#5#11",      "Button",           5, 725+x5, 580+y5, 85, 20, "13sus#5#11", btn_click_13suss5s11)
GUI.New("chord_13sus#5#9#11",      "Button",           5, 725+x5, 605+y5, 85, 20, "13sus#5#9#11", btn_click_13suss5s9s11)


--Suspended Chords Buttons Column 3

GUI.New("chord_13sus#9",      "Button",           5, 815+x5, 55+y5, 85, 20, "13sus#9", btn_click_13suss9)
GUI.New("chord_13sus#9#11",      "Button",           5, 815+x5, 80+y5, 85, 20, "13sus#9#11", btn_click_13suss9s11)
GUI.New("chord_13sus#11",      "Button",           5, 815+x5, 105+y5, 85, 20, "13sus#11", btn_click_13suss11)





local function chord_add_root_note()
    time = reaper.GetCursorPosition()
    markrgnindexnumber, rgnendOut = reaper.GetLastMarkerAndCurRegion(0, time)
    
	  
    retval, isrgnOut, posOut, rgnendOut, nameOut, markrgnindexnumberOut = reaper.EnumProjectMarkers(rgnendOut)
    
    clear_name_flag = 0 --this flag is needed in the SetProjectMarker4 function to enable the region name to be cleared
				    --set to 0 the name is not cleared and when set to 1 the name is cleared regardless of newName value

    --root_name = GUI.elms.root_choice.optarray[ GUI.Val("root_choice") ]
    root_numbers = GUI.Val("root_choice")
    root_names = { [1] = "C", [2] = "C#", [3] = "Db", [4] = "D", [5] = "D#", [6] = "Eb", [7] = "E", [8] = "F", [9] = "F#", [10] = "Gb", [11] = "G", [12] = "G#", [13] = "Ab", [14] = "A", [15] = "A#", [16] = "Bb", [17] = "B"}
    root_name = root_names[root_numbers]

		  
    newName = (nameOut .. "/" .. root_name) --newName = ("C" .. chord_type)
--Msg(newName)
		 
   --- if newName == "" then clear_name_flag = 1 end --if removing the -L leaves an empty name string pass the 1 flag to clear name
    
	   
	   
    reaper.SetProjectMarker4(0, markrgnindexnumberOut, true, posOut, rgnendOut, newName, 0, clear_name_flag)
    
   
    chord_type = ""
 
    
    end
    
    
-- Chords Next Previous Add Split All Tabs (1) Functions 

local function btn_click_chord_add_root_note()
    chord_type = ""
    chord_add_root_note()
    end     

local function btn_click_chord_pre()
    commandID100 = reaper.NamedCommandLookup("_RSa269108c0ba744d947b179c93a57c34399b55a43")
    reaper.Main_OnCommand(commandID100, 0) -- Script: ReaTrak Go to start of previous region.lua
    end
 
local function btn_click_chord_next()
    commandID102 = reaper.NamedCommandLookup("_RSce47da3c9b1238de71cc94a1cb99732b9abd5e41")
    reaper.Main_OnCommand(commandID102, 0) -- Script: ReaTrak Go to start of next region.lua
    end
	   
local function btn_click_chord_new()
    commandID103 = reaper.NamedCommandLookup("_b2314909fa63634ba492c161145cb966")
    reaper.Main_OnCommand(commandID103, 0) -- Custom: Reatrak insert one measure region
    end

local function btn_click_chord_new_selection()
    commandID104 = reaper.NamedCommandLookup("_bd132e9bcaddef4b964432e63a02034b")
    reaper.Main_OnCommand(commandID104, 0) -- Custom: ReaTrak insert chord region in time selection
    end    

local function btn_click_chord_split()
    commandID105 = reaper.NamedCommandLookup("_RS8fa94cd55cd82c3d9b0a066f7f5ceec2009c7180")
    reaper.Main_OnCommand(commandID105, 0) -- Script: ReaTrak Split region under cursor.eel
    end

local function btn_click_chord_sharp_flat()
    commandID106 = reaper.NamedCommandLookup("_RS1004c26d8d7356510044c4e72d5a01625106f68a")
    reaper.Main_OnCommand(commandID106, 0) -- Script: ReaTrak flat sharp change.lua
    end
 



-- Chords Next Previous Add Split All Tabs (layer 1), Tabs 2,3 only (layer 2)
-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x6 = -20
y6 = 20  

GUI.New("chord_add_root_note_btn",      "Button",           2, 50+x6, 620+y6, 115, 20, "Add Root to Chord /", btn_click_chord_add_root_note)
GUI.elms.chord_add_root_note_btn.col_txt = "yellow"
GUI.elms.chord_add_root_note_btn.col_fill = "shot"
GUI.New("chord_pre_btn",      "Button",           6, 170+x6, 620+y6, 115, 20, "< Prevvious Chord", btn_click_chord_pre)
GUI.elms.chord_pre_btn.col_txt = "yellow"
GUI.elms.chord_pre_btn.col_fill = "shot"
GUI.New("chord_next_btn",      "Button",           6, 290+x6, 620+y6, 95, 20, "Next Chord >", btn_click_chord_next)
GUI.elms.chord_next_btn.col_txt = "yellow"
GUI.elms.chord_next_btn.col_fill = "shot"
GUI.New("chord_new_btn",      "Button",           6, 390+x6, 620+y6, 125, 20, "New Chord at Cursor", btn_click_chord_new)
GUI.elms.chord_new_btn.col_txt = "yellow"
GUI.elms.chord_new_btn.col_fill = "shot"
GUI.New("chord_new_selection_btn",      "Button",           6, 520+x6, 620+y6, 135, 20, "New Chord in Selection", btn_click_chord_new_selection)
GUI.elms.chord_new_selection_btn.col_txt = "yellow"
GUI.elms.chord_new_selection_btn.col_fill = "shot"
GUI.New("edit_chord2_btn",      "Button",           6, 660+x6, 620+y6, 70, 20, "Edit Chord", btn_click_edit_chord)
GUI.elms.edit_chord2_btn.col_txt = "yellow"
GUI.elms.edit_chord2_btn.col_fill = "shot"
GUI.New("chord_split_btn",      "Button",           6, 735+x6, 620+y6, 125, 20, "Split Chord at Cursor", btn_click_chord_split)
GUI.elms.chord_split_btn.col_txt = "yellow"
GUI.elms.chord_split_btn.col_fill = "shot"
GUI.New("chord_sharp_flat_btn",      "Button",           6, 865+x6, 620+y6, 40, 20, "♯ / b", btn_click_chord_sharp_flat)
GUI.elms.chord_sharp_flat_btn.col_txt = "yellow"
GUI.elms.chord_sharp_flat_btn.col_fill = "shot"
GUI.New("my_frm2",      "Frame",           6, 500+x6, 650+y6, 410, 40, false, false, "elm_bg", 4)
GUI.elms.my_frm2.text = "Alt Drag Chord Region to move or Drag ends to increase/decrease Length, Alt click to Del"
GUI.elms.my_frm2.col_txt = "white"


-- Button Position Adjustment add e.g x = -10 or x = 0 or x = 10
x7 = 0
y7 = -210

--GUI.New("chord_add_root_note_btn",      "Button",           6, 50+x6, 620+y6, 115, 20, "Add Root to Chord /", btn_click_chord_add_root_note)
--GUI.elms.chord_add_root_note_btn.col_txt = "yellow"
--GUI.elms.chord_add_root_note_btn.col_fill = "shot"
GUI.New("chord_pre2_btn",      "Button",           7, 170+x7, 620+y7, 115, 20, "< Prevvious Chord", btn_click_chord_pre)
GUI.elms.chord_pre2_btn.col_txt = "yellow"
GUI.elms.chord_pre2_btn.col_fill = "shot"
GUI.New("chord_next2_btn",      "Button",           7, 290+x7, 620+y7, 95, 20, "Next Chord >", btn_click_chord_next)
GUI.elms.chord_next2_btn.col_txt = "yellow"
GUI.elms.chord_next2_btn.col_fill = "shot"
GUI.New("chord_new2_btn",      "Button",           7, 390+x7, 620+y7, 125, 20, "New Chord at Cursor", btn_click_chord_new)
GUI.elms.chord_new2_btn.col_txt = "yellow"
GUI.elms.chord_new2_btn.col_fill = "shot"
GUI.New("chord_new2_selection_btn",      "Button",           7, 520+x7, 620+y7, 135, 20, "New Chord in Selection", btn_click_chord_new_selection)
GUI.elms.chord_new2_selection_btn.col_txt = "yellow"
GUI.elms.chord_new2_selection_btn.col_fill = "shot"
GUI.New("edit_chord22_btn",      "Button",           7, 660+x7, 620+y7, 70, 20, "Edit Chord", btn_click_edit_chord)
GUI.elms.edit_chord22_btn.col_txt = "yellow"
GUI.elms.edit_chord22_btn.col_fill = "shot"
GUI.New("chord_split2_btn",      "Button",           7, 735+x7, 620+y7, 125, 20, "Split Chord at Cursor", btn_click_chord_split)
GUI.elms.chord_split2_btn.col_txt = "yellow"
GUI.elms.chord_split2_btn.col_fill = "shot"
GUI.New("chord_sharp_flat2_btn",      "Button",           7, 865+x7, 620+y7, 40, 20, "♯ / b", btn_click_chord_sharp_flat)
GUI.elms.chord_sharp_flat2_btn.col_txt = "yellow"
GUI.elms.chord_sharp_flat2_btn.col_fill = "shot"
GUI.New("my_frm22",      "Frame",           7, 470+x7, 670+y7, 410, 40, false, false, "elm_bg", 4)
GUI.elms.my_frm22.text = "Alt Drag Chord Region to move or Drag ends to increase/decrease Length, Alt click to Del"
GUI.elms.my_frm22.col_txt = "white"

--Chord Root Select



GUI.New("my_frm",      "Frame",           2, 500+x6, 690+y6, 340, 35, true, true, "elm_bg", 4)
GUI.New("root_choice",     "Radio",          2, 32+x6, 664+y6, 410, 64, "Chord Root", ",C,C♯,Db,D,D♯,Eb,E,F,F♯,Gb,G,G♯,Ab,A,A♯,Bb,B", "h", 4)
--Msg("root_choice")
GUI.elms.my_frm.text = " Choose the Root of the Chord then the Chord type or add the Root Note for / Slash Chords"
GUI.elms.my_frm.col_txt = "white"













-- This will be run on every update loop of the GUI script; anything you would put
-- inside a reaper.defer() loop should go here. (The function name doesn't matter)
local function Main()
    --scale = GUI.elms.scale_choice.optarray[ GUI.Val("scale_choice") ]
    --inkey = GUI.elms.key_choice.optarray[ GUI.Val("key_choice") ]
	
	
	--GUI.New("lb_scale",      "Label",           4, 60, 20, scale, true, 1)    
	-- Prevent the user from resizing the window
	--if GUI.resized then
		
		-- If the window's size has been changed, reopen it
		-- at the current position with the size we specified
		--local __,x,y,w,h = gfx.dock(-1,0,0,0,0)
		--gfx.quit()
		--gfx.init(GUI.name, GUI.w, GUI.h, 0, x, y)
		--GUI.redraw_z[0] = true
	--update_buttons()             
    
   end


GUI.Init()

-- Tell the GUI library to run Main on each update loop
-- Individual elements are updated first, then GUI.func is run, then the GUI is redrawn
GUI.func = Main

-- How often (in seconds) to run GUI.func. 0 = every loop.
GUI.freq = 0


GUI.Main()

